import { IJsonSchema } from './assets/IJsonSchema';
import { IValidationInfo } from './validation';
/**
 * Entrance to validate commands.
 * @export
 * @class Validator
 */
export declare class CommandSchemaValidator {
    private static instance;
    /**
     * Creates an instance of CommandSchemaValidator.
     * @memberof CommandSchemaValidator
     */
    private constructor();
    /**
     * Singleton method.
     * @static
     * @returns {CommandSchemaValidator}
     * @memberof CommandSchemaValidator
     */
    static getInstance(): CommandSchemaValidator;
    /**
     * All supported command type to json schema mapping.
     * @static
     * @memberof CommandSchemaValidator
     */
    static COMMAND_TYPE_TO_JSON_SCHEMA: Map<string, IJsonSchema>;
    /**
     * Validate command.
     * @param {object} jsonObject
     * @param {string} commandType
     * @returns {IValidationInfo[]}
     * @memberof CommandSchemaValidator
     */
    validateCommand(jsonObject: object, commandType: string): IValidationInfo[];
}
