import { IJsonSchema } from './assets/IJsonSchema';
import { IValidationInfo } from './validation';
/**
 * Entrance to validate components.
 * @export
 * @class Validator
 */
export declare class ComponentSchemaController {
    /**
     * CustomComponentsExtractor used to extract components from APL template.
     *
     * @private
     * @memberof ComponentSchemaController
     */
    private customComponentsExtractor;
    private static instance;
    /**
     * Creates an instance of ComponentSchemaController.
     * @memberof ComponentSchemaController
     */
    private constructor();
    /**
     * Singleton method.
     * @static
     * @returns {ComponentSchemaController}
     * @memberof ComponentSchemaController
     */
    static getInstance(): ComponentSchemaController;
    /**
     * Check whether a component can contain other components.
     */
    isLayoutComponent(componentName: string, jsonPath: string): boolean;
    isCustomComponent(jsonPath: string): boolean;
    /**
     * Get JSON schema for given component.
     * @static
     * @param {string} componentType
     * @param {string} [parentComponentType]
     * @returns {IJsonSchema}
     * @memberof ComponentSchemaController
     */
    getComponentSchema(aplTemplate: object, componentType: string, parentComponentType?: string): Promise<IJsonSchema>;
    /**
     * Get a list of the supported components.
     * @param {object} aplTemplate
     * @returns {Promise<IJsonSchema>}
     * @memberof ComponentSchemaController
     */
    getAvailableComponents(aplTemplate?: object): Promise<string[]>;
    /**
     * Get a list of the custom components.
     * @param {object} aplTemplate
     * @returns {Promise<IJsonSchema>}
     * @memberof ComponentSchemaController
     */
    getCustomComponents(aplTemplate?: object): Promise<string[]>;
    /**
     * Validate component.
     * @static
     * @param {object} jsonObject
     * @param {string} componentType
     * @param {string} [parentComponent]
     * @returns {IValidationInfo[]}
     * @memberof ComponentSchemaController
     */
    validateComponent(aplTemplate: object, jsonObject: object, componentType: string, parentComponentType?: string): Promise<IValidationInfo[]>;
}
