/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComponentStructureValidator = void 0;
var ImageComponentValidator_1 = require("./validation/validators/ImageComponentValidator");
var FrameComponentValidator_1 = require("./validation/validators/FrameComponentValidator");
var ScrollViewComponentValidator_1 = require("./validation/validators/ScrollViewComponentValidator");
var TextComponetValidator_1 = require("./validation/validators/TextComponetValidator");
var VideoComponentValidator_1 = require("./validation/validators/VideoComponentValidator");
var SequenceComponentValidator_1 = require("./validation/validators/SequenceComponentValidator");
var ComponentValidator_1 = require("./validation/validators/ComponentValidator");
var ContainerComponentValidator_1 = require("./validation/validators/ContainerComponentValidator");
var MultiChildComponentValidator_1 = require("./validation/validators/MultiChildComponentValidator");
/**
 * Entrance to validate component structure.
 * @export
 * @class Validator
 */
var ComponentStructureValidator = /** @class */ (function () {
    /**
     * Constructor
     */
    function ComponentStructureValidator() {
        this.validators = [];
        this.validators.push(new ComponentValidator_1.ComponentValidator());
        this.validators.push(new ContainerComponentValidator_1.ContainerComponentValidator());
        this.validators.push(new FrameComponentValidator_1.FrameComponentValidator());
        this.validators.push(new ImageComponentValidator_1.ImageComponentValidator());
        this.validators.push(new ScrollViewComponentValidator_1.ScrollViewComponentValidator());
        this.validators.push(new SequenceComponentValidator_1.SequenceComponentValidator());
        this.validators.push(new TextComponetValidator_1.TextComponentValidator());
        this.validators.push(new VideoComponentValidator_1.VideoComponentValidator());
        this.validators.push(new MultiChildComponentValidator_1.MultiChildComponentValidator());
    }
    /**
     * Singleton method.
     */
    ComponentStructureValidator.getInstance = function () {
        if (this.instance) {
            return this.instance;
        }
        this.instance = new ComponentStructureValidator();
        return this.instance;
    };
    /**
     * Validate seed component.
     * @param validationSeed seed for validation.
     */
    ComponentStructureValidator.prototype.validate = function (validationSeed) {
        return this.validators
            .map(function (singleValidator) { return singleValidator.validate(validationSeed); })
            .reduce(function (result, nextItem) { return result.concat(nextItem); }, []);
    };
    return ComponentStructureValidator;
}());
exports.ComponentStructureValidator = ComponentStructureValidator;
//# sourceMappingURL=ComponentStructureValidator.js.map