import { IJsonSchema } from './assets/IJsonSchema';
import { IValidationInfo } from './validation';
/**
 * Entrance to validate graphics.
 * @export
 * @class Validator
 */
export declare class GraphicSchemaValidator {
    private static instance;
    /**
     * Creates an instance of GraphicSchemaValidator.
     * @memberof GraphicSchemaValidator
     */
    private constructor();
    /**
     * Singleton method.
     * @static
     * @returns {GraphicSchemaValidator}
     * @memberof GraphicSchemaValidator
     */
    static getInstance(): GraphicSchemaValidator;
    /**
     * All supported graphic type to json schema mapping.
     * @static
     * @memberof GraphicSchemaValidator
     */
    private static GRAPHIC_TYPE_TO_JSON_SCHEMA;
    /**
     * Validate graphic.
     * @param {object} jsonObject
     * @param {string} graphicType
     * @returns {IValidationInfo[]}
     * @memberof GraphicSchemaValidator
     */
    validateGraphic(jsonObject: object, graphicType: string): IValidationInfo[];
    /**
     * Get graphic schema
     * @param {string} graphicType {'root', 'group', 'text', 'path'}
     * @returns {IJsonSchema}
     * @memberof GraphicSchemaValidator
     */
    getGraphicSchema(graphicType: string): IJsonSchema;
}
