import { IValidationInfo } from './validation/index.js';
/**
 * Static apl json template validator.
 * @export
 * @class StaticAplTemplateValidator
 */
export declare class StaticAplTemplateValidator {
    /**
     * AJV validation function used for json schema validation.
     * @private
     * @memberof StaticAplTemplateValidator
     */
    private validateFunction;
    /**
     * Instance of ComponentSchemaController.
     * @private
     * @type {ComponentSchemaController}
     * @memberof StaticAplTemplateValidator
     */
    private componentSchemaController;
    /**
     * Instance of ComponentStructureValidator.
     * @private
     * @type {ComponentStructureValidator}
     * @memberof StaticAplTemplateValidator
     */
    private componentStructureValidator;
    /**
     * Instance of AplComponentsExtractor.
     * @private
     * @type {ComponentSchemaController}
     * @memberof StaticAplTemplateValidator
     */
    private aplComponentExtractor;
    /**
     * instance of ErrorController
     * @private
     * @type {ErrorController}
     * @memberOf StaticAplTemplateValidator
     */
    private errorController;
    /**
     * Instance of CustomComponentsExtractor.
     *
     * @private
     * @type {CustomComponentsExtractor}
     * @memberof StaticAplTemplateValidator
     */
    private customComponentsExtractor;
    /**
     * Instance of AplGraphicsExtractor.
     *
     * @private
     * @type {AplGraphicsExtractor}
     * @memberof StaticAplTemplateValidator
     */
    private aplGraphicsExtractor;
    /**
     * Instance of GraphicSchemaValidator.
     *
     * @private
     * @type {GraphicSchemaValidator}
     * @memberof StaticAplTemplateValidator
     */
    private graphicSchemaValidator;
    /**
     * Instance of AplCommandsExtractor.
     *
     * @private
     * @type {AplCommandsExtractor}
     * @memberof StaticAplTemplateValidator
     */
    private aplCommandsExtractor;
    /**
     * Instance of CommandSchemaValidator.
     *
     * @private
     * @type {CommandSchemaValidator}
     * @memberof StaticAplTemplateValidator
     */
    private commandSchemaValidator;
    /**
     * Creates an instance of StaticAplTemplateValidator.
     * @memberof StaticAplTemplateValidator
     */
    constructor();
    private validateCommands;
    private validateGraphics;
    private validateAllComponents;
    /**
     * Publish validation notification based on given APL template.
     * @param {object} aplTemplate
     * @returns {boolean} to indicate whether given apl template is valid.
     * @memberof StaticAplTemplateValidator
     */
    validate(aplTemplate: object): Promise<IValidationInfo[]>;
    /**
     * Publish validation notification based on given DataSources template.
     * @param {object} dataSources
     * @returns {IValidationInfo[]} validation warnings.
     * @memberof StaticAplTemplateValidator
     */
    validateDataSources(dataSources: object): Promise<IValidationInfo[]>;
    /**
     * Publish validation notification based on given sources.
     * @param {object} sources
     * @returns {IValidationInfo[]} validation warnings.
     * @memberof StaticAplTemplateValidator
     */
    validateSources(sources: object): Promise<IValidationInfo[]>;
    private isObject;
    /**
     * Convert error object to IValidationInfo.
     * @public
     * @param {object} error
     * @returns {IValidationInfo}
     */
    static asValidationWarnInfo(error: object): IValidationInfo;
    private getComponentErrorWithFullPath;
    private isComponentTypeValid;
}
