/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StaticAplTemplateValidator = void 0;
var Ajv_1 = require("./util/Ajv");
var JsonSchema_1 = require("./assets/JsonSchema");
var AVGJSONSchema = require("./assets/graphics/AVG");
var ValidationSeed_1 = require("./validation/ValidationSeed");
var ValidationErrorFilter_1 = require("./util/ValidationErrorFilter");
var IValidationInfo_1 = require("./IValidationInfo");
var AplComponentsExtractor_1 = require("./util/AplComponentsExtractor");
var ComponentSchemaController_1 = require("./ComponentSchemaController");
var ComponentStructureValidator_1 = require("./ComponentStructureValidator");
var IErrorDefinitions_1 = require("./errors/IErrorDefinitions");
var ErrorController_1 = require("./errors/ErrorController");
var CustomComponentsExtractor_1 = require("./util/CustomComponentsExtractor");
var PrimitiveComponentJsonSchemaUtil_1 = require("./util/PrimitiveComponentJsonSchemaUtil");
var AplGraphicsExtractor_1 = require("./util/graphics/AplGraphicsExtractor");
var GraphicSchemaValidator_1 = require("./GraphicSchemaValidator");
var AplCommandsExtractor_1 = require("./util/commands/AplCommandsExtractor");
var CommandSchemaValidator_1 = require("./CommandSchemaValidator");
var VariableStringChecker_1 = require("./util/VariableStringChecker");
/**
 * Static apl json template validator.
 * @export
 * @class StaticAplTemplateValidator
 */
var StaticAplTemplateValidator = /** @class */ (function () {
    /**
     * Creates an instance of StaticAplTemplateValidator.
     * @memberof StaticAplTemplateValidator
     */
    function StaticAplTemplateValidator() {
        if (!Ajv_1.default.getSchema(AVGJSONSchema.JSON_SCHEMA.$id)) {
            Ajv_1.default.addSchema(AVGJSONSchema.JSON_SCHEMA);
        }
        this.validateFunction = Ajv_1.default.getSchema(JsonSchema_1.JSON_SCHEMA.$id) || Ajv_1.default.compile(JsonSchema_1.JSON_SCHEMA);
        this.aplComponentExtractor = AplComponentsExtractor_1.AplComponentsExtractor.getInstance();
        this.componentSchemaController = ComponentSchemaController_1.ComponentSchemaController.getInstance();
        this.componentStructureValidator = ComponentStructureValidator_1.ComponentStructureValidator.getInstance();
        this.errorController = ErrorController_1.ErrorController.getInstance();
        this.customComponentsExtractor = CustomComponentsExtractor_1.CustomComponentsExtractor.getInstance();
        this.aplGraphicsExtractor = AplGraphicsExtractor_1.AplGraphicsExtractor.getInstance();
        this.graphicSchemaValidator = GraphicSchemaValidator_1.GraphicSchemaValidator.getInstance();
        this.aplCommandsExtractor = AplCommandsExtractor_1.AplCommandsExtractor.getInstance();
        this.commandSchemaValidator = CommandSchemaValidator_1.CommandSchemaValidator.getInstance();
    }
    StaticAplTemplateValidator.prototype.validateCommands = function (aplTemplate) {
        var _this = this;
        var commands = this.aplCommandsExtractor.extractCommands(aplTemplate);
        var standardCommandTypes = Array.from(CommandSchemaValidator_1.CommandSchemaValidator.COMMAND_TYPE_TO_JSON_SCHEMA.keys());
        // run schema validation against all standard Commands.
        var schemaErrors = commands
            .filter(function (c) { return standardCommandTypes.includes(c.commandType); })
            .map(function (c) {
            return _this.commandSchemaValidator.validateCommand(c.jsonObject, c.commandType)
                .map(function (e) { return _this.getComponentErrorWithFullPath(e, c.jsonPath); });
        });
        return schemaErrors
            .reduce(function (result, nextItem) { return result.concat(nextItem); }, []);
    };
    StaticAplTemplateValidator.prototype.validateGraphics = function (aplTemplate) {
        var _this = this;
        var graphics = this.aplGraphicsExtractor.extractGraphics(aplTemplate);
        // run schema validation against all APL Graphics.
        var schemaErrors = graphics
            // filter out the root graphics
            .filter(function (g) { return g.graphicType !== undefined; })
            .map(function (g) {
            return _this.graphicSchemaValidator.validateGraphic(g.jsonObject, g.graphicType)
                .map(function (e) { return _this.getComponentErrorWithFullPath(e, g.jsonPath); });
        });
        return schemaErrors
            .reduce(function (result, nextItem) { return result.concat(nextItem); }, []);
    };
    StaticAplTemplateValidator.prototype.validateAllComponents = function (aplTemplate) {
        return __awaiter(this, void 0, void 0, function () {
            var components, primitiveComponentTypes, customComponentTypes, availableComponentTypes, nonCustomComponents, structureErrors, componentErrors, primitiveComponents, schemaErrors, _loop_1, this_1, _i, primitiveComponents_1, c;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        components = this.aplComponentExtractor.extractComponents(aplTemplate);
                        primitiveComponentTypes = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil
                            .getPrimitiveComponentTypes(aplTemplate['version']);
                        return [4 /*yield*/, this.customComponentsExtractor
                                .getCustomComponentTypesAndValidate(aplTemplate)];
                    case 1:
                        customComponentTypes = _a.sent();
                        availableComponentTypes = primitiveComponentTypes.concat(customComponentTypes);
                        nonCustomComponents = components
                            .filter(function (c) { return !_this.componentSchemaController.isCustomComponent(c.jsonPath)
                            && _this.isComponentTypeValid(c, availableComponentTypes); });
                        structureErrors = [];
                        nonCustomComponents.forEach(function (c) {
                            var validationSeed = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed(c.jsonObject, c.jsonPath), new ValidationSeed_1.Seed(c.parentComponent));
                            componentErrors = _this.componentStructureValidator.validate(validationSeed);
                            structureErrors = structureErrors.concat(componentErrors);
                        });
                        primitiveComponents = components
                            .filter(function (item) { return primitiveComponentTypes.includes(item.componentType); });
                        schemaErrors = [];
                        _loop_1 = function (c) {
                            return __generator(this, function (_b) {
                                switch (_b.label) {
                                    case 0: return [4 /*yield*/, this_1.componentSchemaController.validateComponent(aplTemplate, c.jsonObject, c.componentType, c.parentComponentType)];
                                    case 1:
                                        // validation must be sequential for Ajv singleton to cache properly!
                                        componentErrors = _b.sent();
                                        componentErrors = componentErrors.map(function (e) { return _this.getComponentErrorWithFullPath(e, c.jsonPath); });
                                        schemaErrors = schemaErrors.concat(componentErrors);
                                        return [2 /*return*/];
                                }
                            });
                        };
                        this_1 = this;
                        _i = 0, primitiveComponents_1 = primitiveComponents;
                        _a.label = 2;
                    case 2:
                        if (!(_i < primitiveComponents_1.length)) return [3 /*break*/, 5];
                        c = primitiveComponents_1[_i];
                        return [5 /*yield**/, _loop_1(c)];
                    case 3:
                        _a.sent();
                        _a.label = 4;
                    case 4:
                        _i++;
                        return [3 /*break*/, 2];
                    case 5: return [2 /*return*/, structureErrors.concat(schemaErrors)];
                }
            });
        });
    };
    /**
     * Publish validation notification based on given APL template.
     * @param {object} aplTemplate
     * @returns {boolean} to indicate whether given apl template is valid.
     * @memberof StaticAplTemplateValidator
     */
    StaticAplTemplateValidator.prototype.validate = function (aplTemplate) {
        return __awaiter(this, void 0, void 0, function () {
            var componentErrors, filteredErrors, jsonSchemaErrors, uniqueErrors;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.validateAllComponents(aplTemplate)];
                    case 1:
                        componentErrors = _a.sent();
                        return [4 /*yield*/, this.aplGraphicsExtractor.clearJsonPath(aplTemplate)];
                    case 2:
                        _a.sent();
                        if (this.validateFunction(aplTemplate)) {
                            return [2 /*return*/, componentErrors
                                    .concat(this.validateGraphics(aplTemplate))
                                    .concat(this.validateCommands(aplTemplate))];
                        }
                        filteredErrors = ValidationErrorFilter_1.ValidationErrorFilter.filterErrors(this.validateFunction.errors, ValidationErrorFilter_1.ValidationErrorFilter.singleDataPathFilter);
                        jsonSchemaErrors = filteredErrors.map(function (eachError) {
                            return StaticAplTemplateValidator.asValidationWarnInfo(eachError);
                        });
                        uniqueErrors = jsonSchemaErrors.concat(componentErrors.filter(function (componentError) {
                            return jsonSchemaErrors.find(function (schemaError) { return schemaError.path === componentError.path; }) === undefined;
                        }));
                        return [2 /*return*/, uniqueErrors];
                }
            });
        });
    };
    /**
     * Publish validation notification based on given DataSources template.
     * @param {object} dataSources
     * @returns {IValidationInfo[]} validation warnings.
     * @memberof StaticAplTemplateValidator
     */
    StaticAplTemplateValidator.prototype.validateDataSources = function (dataSources) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, Object.keys(dataSources).filter(function (key) { return !_this.isObject(dataSources[key]); })
                        .map(function (key) { return StaticAplTemplateValidator.asValidationWarnInfo({
                        dataPath: "Data.".concat(key),
                        message: "".concat(key, " in DataSources should be an object")
                    }); })];
            });
        });
    };
    /**
     * Publish validation notification based on given sources.
     * @param {object} sources
     * @returns {IValidationInfo[]} validation warnings.
     * @memberof StaticAplTemplateValidator
     */
    StaticAplTemplateValidator.prototype.validateSources = function (sources) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                if (!this.isObject(sources)) {
                    return [2 /*return*/, [
                            StaticAplTemplateValidator.asValidationWarnInfo({
                                dataPath: '',
                                message: 'sources should be an object'
                            })
                        ]];
                }
                return [2 /*return*/, Object.keys(sources).filter(function (key) { return !_this.isObject(sources[key]); })
                        .map(function (key) { return StaticAplTemplateValidator.asValidationWarnInfo({
                        dataPath: "/".concat(key),
                        message: "".concat(key, " in sources should be an object")
                    }); })];
            });
        });
    };
    StaticAplTemplateValidator.prototype.isObject = function (obj) {
        return (!!obj) && (obj.constructor === Object);
    };
    /**
     * Convert error object to IValidationInfo.
     * @public
     * @param {object} error
     * @returns {IValidationInfo}
     */
    StaticAplTemplateValidator.asValidationWarnInfo = function (error) {
        var message = error['message'];
        switch (error['keyword']) {
            case 'enum': {
                message = error['message'] + ' : ' + error['params']['allowedValues'];
                break;
            }
            case 'additionalProperties': {
                message = error['message'] + ' : ' + error['params']['additionalProperty'];
                break;
            }
            case 'pattern': {
                if (error['schemaPath'].indexOf('dimension') >= 0) {
                    message = 'should be number or one of valid dimension : auto,px,dp,vw,vh,%';
                }
                break;
            }
            default: {
                message = error['message'];
            }
        }
        return {
            path: error['dataPath'] === '' ? '/' : error['dataPath'],
            errorMessage: message,
            level: IValidationInfo_1.NotificationLevel.WARN
        };
    };
    StaticAplTemplateValidator.prototype.getComponentErrorWithFullPath = function (componentError, componentPath) {
        if (componentError.path === '/') {
            return __assign(__assign({}, componentError), { path: componentPath });
        }
        else {
            return __assign(__assign({}, componentError), { path: componentPath + componentError.path });
        }
    };
    StaticAplTemplateValidator.prototype.isComponentTypeValid = function (component, availableComponentTypes) {
        if (!component.componentType) {
            this.errorController.triggerValidationError(IErrorDefinitions_1.ErrorDefinitions.COMPONENT_BUILDER_UNABLE_TO_FIND_TYPE.code, {
                item: component.jsonObject,
                path: component.jsonPath
            });
            return false;
        }
        // Not a Primitive component and not a data binding expression(any string contains ${})
        if (!availableComponentTypes.includes(component.componentType) &&
            !(0, VariableStringChecker_1.containsVariableString)(component.componentType)) {
            this.errorController.triggerValidationError(IErrorDefinitions_1.ErrorDefinitions.META_TEMPLATE_UNABLE_TO_FIND_LAYOUT.code, {
                name: component.componentType,
                path: component.jsonPath + '/type'
            });
            return false;
        }
        return true;
    };
    return StaticAplTemplateValidator;
}());
exports.StaticAplTemplateValidator = StaticAplTemplateValidator;
//# sourceMappingURL=StaticAplTemplateValidator.js.map