"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var fs = require("fs");
var sinon = require("sinon");
var ComponentSchemaController_1 = require("../ComponentSchemaController");
var IValidationInfo_1 = require("../IValidationInfo");
var PackageLoader_1 = require("../util/PackageLoader");
var importInternalTemplate_1 = require("../util/__tests__/template_test_cases/importInternalTemplate");
var configs_1 = require("../configs");
var aplTemplate = require("../configs/templates/default_apl.json");
var stub = null;
var componentSchemaController = null;
var validate = function (fileName, componentType, parentComponent) { return __awaiter(void 0, void 0, void 0, function () {
    var data;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                data = fs.readFileSync("src/__tests__/components/".concat(fileName), 'utf8');
                return [4 /*yield*/, componentSchemaController.validateComponent(aplTemplate, JSON.parse(data), componentType, parentComponent)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
var verifyComponent = function (fileName, componentType, parentComponent) { return __awaiter(void 0, void 0, void 0, function () {
    var result;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, validate(fileName, componentType, parentComponent)];
            case 1:
                result = _a.sent();
                (0, chai_1.expect)(result.length).to.equal(0);
                return [2 /*return*/];
        }
    });
}); };
describe('ComponentSchemaController.', function () {
    beforeEach(function () {
        componentSchemaController = ComponentSchemaController_1.ComponentSchemaController.getInstance();
        stub = sinon.stub(PackageLoader_1.PackageLoader.prototype, 'load').returns(new Promise(function (resolve) {
            resolve([{
                    json: importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_13,
                    justLoaded: true,
                    name: 'alexa-layouts'
                }]);
        }));
    });
    afterEach(function () {
        stub.restore();
    });
    it('should validate Container component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var containerDefinitions, _i, containerDefinitions_1, fileName;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    containerDefinitions = fs.readdirSync("src/__tests__/components/")
                        .filter(function (fileName) { return fileName.startsWith('Container') &&
                        !fileName.startsWith('ContainerChildWith'); });
                    _i = 0, containerDefinitions_1 = containerDefinitions;
                    _a.label = 1;
                case 1:
                    if (!(_i < containerDefinitions_1.length)) return [3 /*break*/, 4];
                    fileName = containerDefinitions_1[_i];
                    return [4 /*yield*/, verifyComponent(fileName, 'Container')];
                case 2:
                    _a.sent();
                    _a.label = 3;
                case 3:
                    _i++;
                    return [3 /*break*/, 1];
                case 4: return [2 /*return*/];
            }
        });
    }); });
    it('should validate ContainerChild component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('ContainerChildWithFrame.json', 'Frame', 'Container')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Frame component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('Frame.json', 'Frame')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Frame component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('FrameWithGradient.json', 'Frame')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Image component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: 
                // TODO add it back to Image.json when mixin is implemented. "position": "absolute",
                return [4 /*yield*/, verifyComponent('Image.json', 'Image')];
                case 1:
                    // TODO add it back to Image.json when mixin is implemented. "position": "absolute",
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Image component with sources.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('ImageWithSources.json', 'Image')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate ScrollView component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('ScrollView.json', 'ScrollView')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Sequence component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('Sequence.json', 'Sequence')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Text component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('Text.json', 'Text')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should received correct amount of validation errors.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var data, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    data = fs.readFileSync("src/__tests__/components/ErrorComponent.json", 'utf8');
                    return [4 /*yield*/, componentSchemaController.validateComponent({}, JSON.parse(data), 'Image')];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(8);
                    (0, chai_1.expect)(result[0].path).to.be.equal('/');
                    (0, chai_1.expect)(result[0].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[0].errorMessage).to.include('position');
                    (0, chai_1.expect)(result[1].path).to.be.equal('/');
                    (0, chai_1.expect)(result[1].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[1].errorMessage).to.include('scrim');
                    (0, chai_1.expect)(result[2].path).to.be.equal('/actions/0');
                    (0, chai_1.expect)(result[2].errorMessage).to.include('name');
                    (0, chai_1.expect)(result[2].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[3].path).to.be.equal('/actions/1/enabled');
                    (0, chai_1.expect)(result[3].errorMessage).to.include('boolean');
                    (0, chai_1.expect)(result[3].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[4].path).to.be.equal('/layoutDirection');
                    (0, chai_1.expect)(result[4].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[5].path).to.be.equal('/role');
                    (0, chai_1.expect)(result[5].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[6].path).to.be.equal('/width');
                    (0, chai_1.expect)(result[6].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    (0, chai_1.expect)(result[7].path).to.be.equal('/filters/0/kind');
                    (0, chai_1.expect)(result[7].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Image component correctly with mixin support.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var data, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    data = fs.readFileSync("src/__tests__/components/ImageWithMixin.json", 'utf8');
                    return [4 /*yield*/, componentSchemaController.validateComponent({}, JSON.parse(data), 'Image', 'Container')];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(0);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get custom component json schema correctly.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var apl, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    apl = (0, configs_1.getSampleTemplate)(configs_1.SampleTemplateName.TEXT_LIST).apl;
                    return [4 /*yield*/, componentSchemaController.getComponentSchema(apl, 'AlexaHeader', undefined)];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(Object.keys(result.properties)).to.have.length(10);
                    (0, chai_1.expect)(result.properties.type.type).to.be.equal('string');
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Image component correctly with mixin support.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var data, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    data = fs.readFileSync("src/__tests__/components/ImageWithMixinError.json", 'utf8');
                    return [4 /*yield*/, componentSchemaController.validateComponent({}, JSON.parse(data), 'Image', 'Container')];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(2);
                    (0, chai_1.expect)(result[0].path).to.be.equal('/');
                    return [2 /*return*/];
            }
        });
    }); });
    it('should return a list of supported components.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var apl, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    apl = (0, configs_1.getSampleTemplate)(configs_1.SampleTemplateName.TEXT_LIST).apl;
                    return [4 /*yield*/, componentSchemaController.getAvailableComponents(apl)];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(15);
                    (0, chai_1.expect)(result.includes('Image')).to.be.equal(true);
                    (0, chai_1.expect)(result.includes('AlexaHeader')).to.be.equal(true);
                    return [4 /*yield*/, componentSchemaController.getAvailableComponents()];
                case 2:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(13);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should check whether component can contain other components correctly.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            (0, chai_1.expect)(componentSchemaController.isLayoutComponent('Image')).to.be.equal(false);
            (0, chai_1.expect)(componentSchemaController.isLayoutComponent('Container', 'whateverpath')).to.be.equal(true);
            (0, chai_1.expect)(componentSchemaController.isLayoutComponent('mainTemplate', '/mainTemplate')).to.be.equal(true);
            (0, chai_1.expect)(componentSchemaController.isLayoutComponent('customComponent', '/layouts/customComponent')).to.be.equal(true);
            (0, chai_1.expect)(componentSchemaController.isLayoutComponent('anyothercustomComponent', '/mainTemplate/items/0/customComponent')).to.be.equal(false);
            return [2 /*return*/];
        });
    }); });
    it('should validate TouchWrapper component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('TouchWrapper.json', 'TouchWrapper')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate VectorGraphic component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('VectorGraphic.json', 'VectorGraphic')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate VectorGraphic component with sources.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('VectorGraphicWithSources.json', 'VectorGraphic')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate GridSequence component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('GridSequence.json', 'GridSequence')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate EditText component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('EditText.json', 'EditText')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Pager component with onSpeechMark and onChildrenChanged.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('Pager.json', 'Pager')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Video component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('Video.json', 'Video')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should NOT allow textTrack and textTracks in Video component.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, validate('VideoTextTracksError.json', 'Video')];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.equal(3);
                    (0, chai_1.expect)(result[0].errorMessage).to.equal('should have required property \'type\'');
                    (0, chai_1.expect)(result[1].errorMessage).to.equal('should be equal to one of the allowed values : caption');
                    (0, chai_1.expect)(result[2].errorMessage).to.equal('should NOT be valid');
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate Extension component', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyComponent('ExtensionComponent.json', 'ExtensionComponent')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should find 1 error in handleVisibilityChange.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, validate('VisibilityChangeHandler.json', 'Text')];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(1);
                    (0, chai_1.expect)(result[0].path).to.be.equal('/handleVisibilityChange/0/when');
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=ComponentSchemaController.spec.js.map