"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var fs = require("fs");
var IValidationInfo_1 = require("../IValidationInfo");
var GraphicSchemaValidator_1 = require("../GraphicSchemaValidator");
var AVGPathItemJSONSchema = require("../assets/graphics/AVGPathItem");
var AVGJSONSchema = require("../assets/graphics/AVG");
describe('GraphicSchemaValidator.', function () {
    var graphicSchemaValidator = GraphicSchemaValidator_1.GraphicSchemaValidator.getInstance();
    it('should validate group graphic.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyGraphic('AVGGroupItem.json', 'group')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate path graphic.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyGraphic('AVGPathItem.json', 'path')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should received correct amount of validation errors.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var data, result;
        return __generator(this, function (_a) {
            data = fs.readFileSync("src/__tests__/graphics/ErrorGraphic.json", 'utf8');
            result = graphicSchemaValidator.validateGraphic(JSON.parse(data), 'path');
            (0, chai_1.expect)(result.length).to.be.equal(10);
            (0, chai_1.expect)(result[0].path).to.be.equal('/');
            (0, chai_1.expect)(result[0].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[0].errorMessage).to.include('pathData');
            (0, chai_1.expect)(result[1].path).to.be.equal('/');
            (0, chai_1.expect)(result[1].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[2].path).to.be.equal('/');
            (0, chai_1.expect)(result[2].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[3].path).to.be.equal('/bind/0');
            (0, chai_1.expect)(result[3].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[3].errorMessage).to.include('value');
            (0, chai_1.expect)(result[4].path).to.be.equal('/filters/0/type');
            (0, chai_1.expect)(result[4].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[5].path).to.be.equal('/filters/0/horizontalOffset');
            (0, chai_1.expect)(result[5].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[6].path).to.be.equal('/when');
            (0, chai_1.expect)(result[6].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[7].path).to.be.equal('/fill');
            (0, chai_1.expect)(result[7].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[8].path).to.be.equal('/pathLength');
            (0, chai_1.expect)(result[8].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            (0, chai_1.expect)(result[9].path).to.be.equal('/stroke');
            (0, chai_1.expect)(result[9].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
            return [2 /*return*/];
        });
    }); });
    it('should return path graphic schema.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            result = graphicSchemaValidator.getGraphicSchema('path');
            (0, chai_1.expect)(result).to.deep.equal(AVGPathItemJSONSchema.JSON_SCHEMA);
            return [2 /*return*/];
        });
    }); });
    it('should return root graphics schema.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            result = graphicSchemaValidator.getGraphicSchema('root');
            (0, chai_1.expect)(result).to.deep.equal(AVGJSONSchema.JSON_SCHEMA);
            return [2 /*return*/];
        });
    }); });
    function verifyGraphic(fileName, type) {
        return __awaiter(this, void 0, void 0, function () {
            var data, result;
            return __generator(this, function (_a) {
                data = fs.readFileSync("src/__tests__/graphics/".concat(fileName), 'utf8');
                result = graphicSchemaValidator.validateGraphic(JSON.parse(data), type);
                (0, chai_1.expect)(result.length).to.be.equal(0);
                return [2 /*return*/];
            });
        });
    }
});
//# sourceMappingURL=GraphicSchemaValidator.spec.js.map