/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/* tslint:disable */
'use strict';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSON_SCHEMA = void 0;
var IJsonSchema_1 = require("./IJsonSchema");
var BaseComponent_1 = require("./BaseComponent");
exports.JSON_SCHEMA = {
    "$schema": IJsonSchema_1.SCHEMA_URI,
    "definitions": BaseComponent_1.JSON_SCHEMA.definitions,
    "type": "object",
    "properties": __assign(__assign({}, BaseComponent_1.JSON_SCHEMA.properties), { "data": {
            "$ref": "#/definitions/anyArray",
            "category": IJsonSchema_1.Categories.container,
            "description": "Data to bind into this container.  This should be an array of data items. Each item will be bound to the 'data' global variable and the 'item' component will be inflated using that data item.  The 'index' global variable will be assigned the 0-based array offset of the item. The 'ordinal' global variable will be assigned for each 'numbered' child"
        }, "firstItem": {
            "$ref": "#/definitions/ComponentArray",
            "category": IJsonSchema_1.Categories.container,
            "description": "A child component to put at the beginning of the layout."
        }, "lastItem": {
            "$ref": "#/definitions/ComponentArray",
            "category": IJsonSchema_1.Categories.container,
            "description": "A child component to put at the end of the layout"
        }, "onChildrenChanged": {
            "$ref": "#/definitions/CommandArray",
            "category": IJsonSchema_1.Categories.container,
            "description": "Command to execute when the children were inserted or removed from the component."
        }, "numbered": {
            "type": "boolean",
            "category": IJsonSchema_1.Categories.container,
            "description": "If true, assign ordinal numbers to the children"
        }, "alignItems": {
            "type": "string",
            "category": IJsonSchema_1.Categories.container,
            "description": "Specifies default alignment for children in the cross-axis.",
            "enum": [
                "stretch",
                "center",
                "start",
                "end",
                "baseline"
            ]
        }, "direction": {
            "type": "string",
            "category": IJsonSchema_1.Categories.container,
            "description": "The direction that children will laid out in.",
            "enum": [
                "column",
                "row",
                "columnReverse",
                "rowReverse"
            ]
        }, "justifyContent": {
            "type": "string",
            "category": IJsonSchema_1.Categories.container,
            "description": "Distribute free space when there is room on the main axis.",
            "enum": [
                "start",
                "end",
                "center",
                "spaceBetween",
                "spaceAround",
                "spaceEvenly"
            ]
        }, "wrap": {
            "type": "string",
            "category": IJsonSchema_1.Categories.container,
            "description": "How children will be wrapped to multiple lines",
            "enum": [
                "noWrap",
                "wrap",
                "wrapReverse"
            ]
        }, "item": {}, "items": {} }),
    "required": [
        "type"
    ],
    "description": "A layout that uses Flexbox to position its children.",
    "additionalProperties": false
};
//# sourceMappingURL=Container.js.map