/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/* tslint:disable */
'use strict';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSON_SCHEMA = void 0;
var commonDefinition = require("./CommonDefinition");
var IJsonSchema_1 = require("./IJsonSchema");
var BaseComponent_1 = require("./BaseComponent");
exports.JSON_SCHEMA = {
    "$schema": IJsonSchema_1.SCHEMA_URI,
    "definitions": __assign(__assign({}, BaseComponent_1.JSON_SCHEMA.definitions), { "ColorArray": commonDefinition.ColorArray, "Gradient": commonDefinition.Gradient, "number": {
            "type": "number"
        }, "numberArray": commonDefinition.numberArray }),
    "type": "object",
    "properties": __assign(__assign({}, BaseComponent_1.JSON_SCHEMA.properties), { "item": {}, "items": {}, "background": {
            "anyOf": [
                {
                    "$ref": "#/definitions/color"
                },
                {
                    "$ref": "#/definitions/Gradient"
                }
            ],
            "category": IJsonSchema_1.Categories.frame,
            "description": "Background color or gradient of the shape"
        }, "backgroundColor": {
            "$ref": "#/definitions/color",
            "category": IJsonSchema_1.Categories.frame,
            "deprecated": true,
            "deprecationMessage": "Deprecated from APL 2023.3. Please use background instead."
        }, "borderColor": {
            "$ref": "#/definitions/color",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Border color of this component"
        }, "borderRadius": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Common radius of the corners of the shape."
        }, "borderStrokeWidth": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Width of the border stroke."
        }, "borderWidth": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Width of the border."
        }, "borderTopLeftRadius": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Radius of the top-left corner. Overrides borderRadius"
        }, "borderTopRightRadius": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Radius of the top-right corner. Overrides borderRadius"
        }, "borderBottomLeftRadius": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Radius of the bottom-left corner. Overrides borderRadius"
        }, "borderBottomRightRadius": {
            "$ref": "#/definitions/dimension",
            "category": IJsonSchema_1.Categories.frame,
            "description": "Radius of the bottom-right corner. Overrides borderRadius"
        } }),
    "required": [
        "type"
    ],
    "description": "Display a border and background",
    "additionalProperties": false
};
//# sourceMappingURL=Frame.js.map