/**
 * JsonSchema definition.
 */
export interface IJsonSchema extends Object {
    /**
     * Id of the JSON schema.
     */
    $id?: string;
    /**
     * Reference of the JSON schema.
     */
    $ref?: string;
    /**
     * It is recommended that the meta-schema is
     * included in the root of any JSON Schema
     */
    $schema?: string;
    /**
     * Schema description.
     */
    description?: string;
    /**
     * Default json for the object represented by
     * this schema
     */
    default?: any;
    /**
     * Required fields.
     */
    required?: string[];
    /**
     * Holds simple JSON Schema definitions for
     * referencing from elsewhere.
     */
    definitions?: {
        [property: string]: IJsonSchema;
    };
    /**
     * The keys that can exist on the object with the
     * json schema that should validate their value
     */
    properties?: {
        [key: string]: IJsonSchema;
    };
    /**
     * The basic type of this schema, can be one of
     * [string, number, object, array, boolean, null]
     * or an array of the acceptable types
     */
    type?: string | string[] | object;
    /**
     * Indicate whether additional properties is allowed.
     */
    additionalProperties?: boolean;
    /**
     * Indicate whether unevaluated properties is not allowed.
     */
    unevaluatedProperties?: boolean;
    /**
     * Optional items fields containing all children items.
     */
    items?: IJsonSchema;
    /**
     * Combining Schema.
     */
    anyOf?: IJsonSchema[];
    oneOf?: IJsonSchema[];
    allOf?: IJsonSchema[];
    not?: IJsonSchema;
    /**
     * Enumerates the values that this schema can be
     * e.g.
     * {"type": "string",
     *  "enum": ["red", "green", "blue"]}
     */
    enum?: any[];
    const?: any;
    /**
     * The key of this object is a regex for which
     * properties the schema applies to
     */
    patternProperties?: {
        [pattern: string]: IJsonSchema;
    };
    /**
     * This is a regex string that the value must conform to.
     */
    pattern?: string;
    /**
     * minimum value that should be exclusive
     */
    exclusiveMinimum?: number;
    minimum?: number;
    /**
     * Categorization support for formUI.
     */
    category?: Categories;
    /**
     * If-Then in JSON Schema
     */
    if?: IJsonSchema;
    then?: IJsonSchema;
    else?: IJsonSchema;
    deprecated?: boolean;
    deprecationMessage?: string;
}
export declare enum Categories {
    container = "Container",
    image = "Image",
    text = "Text",
    video = "Video",
    sequence = "Sequence",
    scrollView = "ScrollView",
    frame = "Frame",
    touchWrapper = "TouchWrapper",
    pager = "Pager",
    vectorGraphic = "VectorGraphic",
    aboutComponent = "About Component",
    width = "Width",
    height = "Height",
    padding = "Padding",
    alignmentAndPosition = "Alignment and Position",
    gridSequence = "GridSequence",
    editText = "EditText",
    extension = "ExtensionComponent"
}
export declare const SCHEMA_URI = "https://json-schema.org/draft/2019-09/schema";
