"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSampleTemplate = exports.getSampleTemplates = exports.getDefaultAplDocument = exports.SampleTemplateName = void 0;
var detailImageRightApl = require("./templates/detail-image-right.json");
var detailImageLeftApl = require("./templates/detail-image-left.json");
var gridListDarkApl = require("./templates/grid-list-dark.json");
var headlineDarkApl = require("./templates/headline-dark.json");
var imageListDarkApl = require("./templates/image-list-dark.json");
var paginatedListDarkApl = require("./templates/paginated-list-dark.json");
var textListDarkApl = require("./templates/text-list-dark.json");
var detailImageRightLightApl = require("./templates/detail-image-right-light.json");
var gridListLightApl = require("./templates/grid-list-light.json");
var headlineLightApl = require("./templates/headline-light.json");
var imageListLightApl = require("./templates/image-list-light.json");
var paginatedListLightApl = require("./templates/paginated-list-light.json");
var textListLightApl = require("./templates/text-list-light.json");
var videoPlayerApl = require("./templates/video-player.json");
var imageDisplayApl = require("./templates/image-display.json");
var longTextApl = require("./templates/long-text.json");
var checkListApl = require("./templates/check-list.json");
var aplAnalogClockApl = require("./templates/apl-analog-clock.json");
var aplEqualizerApl = require("./templates/apl-equalizer.json");
var aplAnimateLeafsBgApl = require("./templates/apl-animate-leafs-bg.json");
var parallaxEffectApl = require("./templates/parallax-effect.json");
var animationApl = require("./templates/animation.json");
var defaultApl = require("./templates/default_apl.json");
var fullscreenVideoPlayerApl = require("./templates/apl-video.json");
var cardsLayoutApl = require("./templates/apl-cards-layout.json");
var audioPlayerApl = require("./templates/apl-audio.json");
var multipleChoiceApl = require("./templates/apl-multiple-choice.json");
var simpleTextApl = require("./templates/apl-simple-text.json");
var mrbHeadlineApl = require("./templates/mrb-headline.json");
var detailImageRightData = require("./data/detail_image_right_data.json");
var detailImageLeftData = require("./data/detail_image_left_data.json");
var gridListDarkData = require("./data/grid_list_dark_data.json");
var headlineDarkData = require("./data/headline_dark_data.json");
var imageListDarkData = require("./data/image_list_dark_data.json");
var paginatedListDarkData = require("./data/paginated_list_dark_data.json");
var textListDarkData = require("./data/text_list_dark_data.json");
var detailImageRightLightData = require("./data/detail_image_right_light_data.json");
var grigListLightData = require("./data/grid_list_light_data.json");
var headlineLightData = require("./data/headline_light_data.json");
var imageListLightData = require("./data/image_list_light_data.json");
var paginatedListLightData = require("./data/paginated_list_light_data.json");
var textListLightData = require("./data/text_list_light_data.json");
var videoPlayerData = require("./data/video_player_data.json");
var imageDisplayData = require("./data/image_display_data.json");
var longTextData = require("./data/long_text_data.json");
var checkListData = require("./data/check_list_data.json");
var aplAnalogClockData = require("./data/apl_analog_clock_data.json");
var aplEqualizerData = require("./data/apl_equalizer_data.json");
var aplAnimateLeafsBgData = require("./data/apl_animate_leafs_bg_data.json");
var parallaxEffectData = require("./data/parallax_effect_data.json");
var animationData = require("./data/animation_data.json");
var fullscreenVideoPlayerData = require("./data/apl_video_data.json");
var cardsLayoutData = require("./data/apl_cards_layout_data.json");
var audioPlayerData = require("./data/apl_audio_data.json");
var multipleChoiceData = require("./data/apl_multiple_choice_data.json");
var simpleTextData = require("./data/apl_simple_text_data.json");
var mrbGridListData = require("./data/mrb_grid_list_data.json");
var mrbHeadlineData = require("./data/mrb_headline_data.json");
var mrbImageListData = require("./data/mrb_image_list_data.json");
var mrbPaginatedListData = require("./data/mrb_paginated_list_data.json");
var mrbTextListData = require("./data/mrb_text_list_data.json");
var defaultData = require("./data/default_data.json");
var longTextSampleApl = require("./templates/long-text-sample.json");
var imageRightDetailApl = require("./templates/image-right-detail-sample.json");
var imageLeftDetailApl = require("./templates/image-left-detail-sample.json");
var shortTextApl = require("./templates/short-text-sample.json");
var imageDisplaySampleApl = require("./templates/image-display-sample.json");
var textForwardListApl = require("./templates/text-forward-list-sample.json");
var imageForwardlistApl = require("./templates/image-forward-list-sample.json");
var longTextSampleData = require("./data/long_text_sample_data.json");
var imageRightDetailData = require("./data/image_right_detail_sample_data.json");
var imageLeftDetailData = require("./data/image_left_detail_sample_data.json");
var shortTextData = require("./data/short_text_sample_data.json");
var imageDisplaySampleData = require("./data/image_display_sample_data.json");
var textForwardListData = require("./data/text_forward_list_sample_data.json");
var imageForwardListData = require("./data/image_forward_list_sample_data.json");
var immutable_1 = require("immutable");
/**
 * This is a enum that contains the names of sample templates.
 */
var SampleTemplateName;
(function (SampleTemplateName) {
    SampleTemplateName["IMAGE_RIGHT_DETAIL"] = "IMAGE_RIGHT_DETAIL";
    SampleTemplateName["IMAGE_LEFT_DETAIL"] = "IMAGE_LEFT_DETAIL";
    SampleTemplateName["GRID_LIST"] = "GRID_LIST";
    SampleTemplateName["HEADLINE"] = "HEADLINE";
    SampleTemplateName["IMAGE_LIST"] = "IMAGE_LIST";
    SampleTemplateName["PAGINATED_LIST"] = "PAGINATED_LIST";
    SampleTemplateName["TEXT_LIST"] = "TEXT_LIST";
    SampleTemplateName["DETAILS"] = "DETAILS";
    SampleTemplateName["GRID"] = "GRID";
    SampleTemplateName["SHORT_TEXT"] = "SHORT_TEXT";
    SampleTemplateName["HORIZONTAL_LIST"] = "HORIZONTAL_LIST";
    SampleTemplateName["FULL_SCREEN_LIST"] = "FULL_SCREEN_LIST";
    SampleTemplateName["VERTICAL_LIST"] = "VERTICAL_LIST";
    SampleTemplateName["VIDEO_PLAYER"] = "VIDEO_PLAYER";
    SampleTemplateName["IMAGE_DISPLAY"] = "IMAGE_DISPLAY";
    SampleTemplateName["FULL_TEXT"] = "FULL_TEXT";
    SampleTemplateName["CHECK_LIST"] = "CHECK_LIST";
    SampleTemplateName["ANALOG_CLOCK"] = "ANALOG_CLOCK";
    SampleTemplateName["DANCING_EQUALIZER_BARS"] = "DANCING_EQUALIZER_BARS";
    SampleTemplateName["PARALLAX_EFFECT"] = "PARALLAX_EFFECT";
    SampleTemplateName["ANIMATED_BACKGROUND"] = "ANIMATED_BACKGROUND";
    SampleTemplateName["ANIMATION"] = "ANIMATION";
    SampleTemplateName["START_FROM_SCRATCH"] = "START_FROM_SCRATCH";
    SampleTemplateName["LONG_TEXT_SAMPLE"] = "LONG_TEXT_SAMPLE";
    SampleTemplateName["IMAGE_RIGHT_DETAIL_SAMPLE"] = "IMAGE_RIGHT_DETAIL_SAMPLE";
    SampleTemplateName["IMAGE_LEFT_DETAIL_SAMPLE"] = "IMAGE_LEFT_DETAIL_SAMPLE";
    SampleTemplateName["SHORT_TEXT_SAMPLE"] = "SHORT_TEXT_SAMPLE";
    SampleTemplateName["IMAGE_DISPLAY_SAMPLE"] = "IMAGE_DISPLAY_SAMPLE";
    SampleTemplateName["TEXT_FORWARD_LIST_SAMPLE"] = "TEXT_FORWARD_LIST_SAMPLE";
    SampleTemplateName["IMAGE_FORWARD_LIST_SAMPLE"] = "IMAGE_FORWARD_LIST_SAMPLE";
    SampleTemplateName["CARDS_LAYOUT"] = "CARDS_LAYOUT";
    SampleTemplateName["SIMPLE_TEXT_AND_IMAGE"] = "SIMPLE_TEXT_AND_IMAGE";
    SampleTemplateName["MULTIPLE_CHOICE"] = "MULTIPLE_CHOICE";
    SampleTemplateName["FULLSCREEN_VIDEO_PLAYER"] = "FULLSCREEN_VIDEO_PLAYER";
    SampleTemplateName["AUDIO_PLAYER"] = "AUDIO_PLAYER";
    SampleTemplateName["MRB_GRID_LIST"] = "MRB_GRID_LIST";
    SampleTemplateName["MRB_HEADLINE"] = "MRB_HEADLINE";
    SampleTemplateName["MRB_IMAGE_LIST"] = "MRB_IMAGE_LIST";
    SampleTemplateName["MRB_PAGINATED_LIST"] = "MRB_PAGINATED_LIST";
    SampleTemplateName["MRB_TEXT_LIST"] = "MRB_TEXT_LIST";
})(SampleTemplateName = exports.SampleTemplateName || (exports.SampleTemplateName = {}));
/**
 * This is a mapping that contains the contents of sample templates.
 */
var SAMPLE_TEMPLATE_METADATA = (0, immutable_1.Map)({
    IMAGE_RIGHT_DETAIL: {
        apl: detailImageRightApl,
        data: detailImageRightData
    },
    IMAGE_LEFT_DETAIL: {
        apl: detailImageLeftApl,
        data: detailImageLeftData
    },
    GRID_LIST: {
        apl: gridListDarkApl,
        data: gridListDarkData
    },
    HEADLINE: {
        apl: headlineDarkApl,
        data: headlineDarkData
    },
    IMAGE_LIST: {
        apl: imageListDarkApl,
        data: imageListDarkData
    },
    PAGINATED_LIST: {
        apl: paginatedListDarkApl,
        data: paginatedListDarkData
    },
    TEXT_LIST: {
        apl: textListDarkApl,
        data: textListDarkData
    },
    DETAILS: {
        apl: detailImageRightLightApl,
        data: detailImageRightLightData
    },
    GRID: {
        apl: gridListLightApl,
        data: grigListLightData
    },
    SHORT_TEXT: {
        apl: headlineLightApl,
        data: headlineLightData
    },
    HORIZONTAL_LIST: {
        apl: imageListLightApl,
        data: imageListLightData
    },
    FULL_SCREEN_LIST: {
        apl: paginatedListLightApl,
        data: paginatedListLightData
    },
    VERTICAL_LIST: {
        apl: textListLightApl,
        data: textListLightData
    },
    VIDEO_PLAYER: {
        apl: videoPlayerApl,
        data: videoPlayerData
    },
    IMAGE_DISPLAY: {
        apl: imageDisplayApl,
        data: imageDisplayData
    },
    FULL_TEXT: {
        apl: longTextApl,
        data: longTextData
    },
    CHECK_LIST: {
        apl: checkListApl,
        data: checkListData
    },
    ANALOG_CLOCK: {
        apl: aplAnalogClockApl,
        data: aplAnalogClockData
    },
    DANCING_EQUALIZER_BARS: {
        apl: aplEqualizerApl,
        data: aplEqualizerData
    },
    ANIMATED_BACKGROUND: {
        apl: aplAnimateLeafsBgApl,
        data: aplAnimateLeafsBgData
    },
    PARALLAX_EFFECT: {
        apl: parallaxEffectApl,
        data: parallaxEffectData
    },
    ANIMATION: {
        apl: animationApl,
        data: animationData
    },
    START_FROM_SCRATCH: {
        apl: defaultApl,
        data: defaultData
    },
    LONG_TEXT_SAMPLE: {
        apl: longTextSampleApl,
        data: longTextSampleData
    },
    IMAGE_RIGHT_DETAIL_SAMPLE: {
        apl: imageRightDetailApl,
        data: imageRightDetailData
    },
    IMAGE_LEFT_DETAIL_SAMPLE: {
        apl: imageLeftDetailApl,
        data: imageLeftDetailData
    },
    SHORT_TEXT_SAMPLE: {
        apl: shortTextApl,
        data: shortTextData
    },
    IMAGE_DISPLAY_SAMPLE: {
        apl: imageDisplaySampleApl,
        data: imageDisplaySampleData
    },
    TEXT_FORWARD_LIST_SAMPLE: {
        apl: textForwardListApl,
        data: textForwardListData
    },
    IMAGE_FORWARD_LIST_SAMPLE: {
        apl: imageForwardlistApl,
        data: imageForwardListData
    },
    CARDS_LAYOUT: {
        apl: cardsLayoutApl,
        data: cardsLayoutData
    },
    SIMPLE_TEXT_AND_IMAGE: {
        apl: simpleTextApl,
        data: simpleTextData
    },
    MULTIPLE_CHOICE: {
        apl: multipleChoiceApl,
        data: multipleChoiceData
    },
    FULLSCREEN_VIDEO_PLAYER: {
        apl: fullscreenVideoPlayerApl,
        data: fullscreenVideoPlayerData
    },
    AUDIO_PLAYER: {
        apl: audioPlayerApl,
        data: audioPlayerData
    },
    MRB_GRID_LIST: {
        apl: gridListDarkApl,
        data: mrbGridListData
    },
    MRB_HEADLINE: {
        apl: mrbHeadlineApl,
        data: mrbHeadlineData
    },
    MRB_IMAGE_LIST: {
        apl: imageListDarkApl,
        data: mrbImageListData
    },
    MRB_PAGINATED_LIST: {
        apl: paginatedListDarkApl,
        data: mrbPaginatedListData
    },
    MRB_TEXT_LIST: {
        apl: textListDarkApl,
        data: mrbTextListData
    }
});
function getDefaultAplDocument() {
    return defaultApl;
}
exports.getDefaultAplDocument = getDefaultAplDocument;
function getSampleTemplates() {
    return SAMPLE_TEMPLATE_METADATA;
}
exports.getSampleTemplates = getSampleTemplates;
function getSampleTemplate(name) {
    return SAMPLE_TEMPLATE_METADATA.get(name);
}
exports.getSampleTemplate = getSampleTemplate;
//# sourceMappingURL=SampleTemplate.js.map