"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultViewport = exports.getDefaultViewportProfile = exports.getViewportProfiles = exports.ViewportType = exports.ViewportMode = exports.ViewportShape = void 0;
var immutable_1 = require("immutable");
var hubRound = require("./viewportProfiles/hubRound.json");
var hubLandscapeSmall = require("./viewportProfiles/hubLandscapeSmall.json");
var hubLandscapeMedium = require("./viewportProfiles/hubLandscapeMedium.json");
var hubLandscape = require("./viewportProfiles/hubLandscape.json");
var hubLandscapeExtraLarge = require("./viewportProfiles/hubLandscapeXL.json");
var hubPortraitMedium = require("./viewportProfiles/hubLandscapePortraitMedium.json");
var tvFullscreen = require("./viewportProfiles/tvFullscreen.json");
var mobileSmall = require("./viewportProfiles/mobileSmall.json");
var mobileMedium = require("./viewportProfiles/mobileMedium.json");
var mobileLarge = require("./viewportProfiles/mobileLarge.json");
/**
 * Shape of viewport profile
 * Reference: https://developer.amazon.com/en-US/docs/alexa/alexa-presentation-language/apl-viewport-property.html#shape
 * @export
 * @enum {string}
 */
var ViewportShape;
(function (ViewportShape) {
    ViewportShape["ROUND"] = "round";
    ViewportShape["RECTANGLE"] = "rectangle";
})(ViewportShape = exports.ViewportShape || (exports.ViewportShape = {}));
/**
 * Mode of viewport profile
 * Reference:
 * Reference:https://developer.amazon.com/en-US/docs/alexa/alexa-presentation-language/apl-viewport-property.html
 * #viewport_mode_property
 * @export
 * @enum {string}
 */
var ViewportMode;
(function (ViewportMode) {
    ViewportMode["HUB"] = "hub";
    ViewportMode["TV"] = "tv";
    ViewportMode["MOBILE"] = "mobile";
    ViewportMode["AUTO"] = "auto";
})(ViewportMode = exports.ViewportMode || (exports.ViewportMode = {}));
/**
 * Type of viewport profile
 * @export
 * @enum {string}
 */
var ViewportType;
(function (ViewportType) {
    ViewportType["STANDARD"] = "standard";
    ViewportType["OVERLAY"] = "overlay";
})(ViewportType = exports.ViewportType || (exports.ViewportType = {}));
var HUB_LANDSCAPE = hubLandscape;
/**
 * This is a mapping that contains the contents of vieport profiles.
 */
var VIEWPORT_PROFILE_METADATA = (0, immutable_1.OrderedMap)({
    hubRound: hubRound,
    hubLandscapeSmall: hubLandscapeSmall,
    hubLandscapeMedium: hubLandscapeMedium,
    hubLandscape: HUB_LANDSCAPE,
    hubLandscapeExtraLarge: hubLandscapeExtraLarge,
    hubPortraitMedium: hubPortraitMedium,
    tvFullscreen: tvFullscreen,
    mobileSmall: mobileSmall,
    mobileMedium: mobileMedium,
    mobileLarge: mobileLarge
});
/**
 * Get viewport profiles.
 * @returns {OrderedMap<string, IViewportProfile>}
 */
function getViewportProfiles() {
    return VIEWPORT_PROFILE_METADATA;
}
exports.getViewportProfiles = getViewportProfiles;
/**
 * Default viewport profile
 * @export
 */
function getDefaultViewportProfile() {
    return HUB_LANDSCAPE;
}
exports.getDefaultViewportProfile = getDefaultViewportProfile;
/**
 * Default viewport
 * @export
 */
function getDefaultViewport() {
    return __assign(__assign({}, getDefaultViewportProfile().exampleDevices[0]), { shape: getDefaultViewportProfile().shape });
}
exports.getDefaultViewport = getDefaultViewport;
//# sourceMappingURL=ViewportProfile.js.map