import { IValidationError } from './IError';
import { IErrorInterface } from './IErrorInterface';
/**
 * ErrorController is used to control the errors in the renderer, and react when they occur.
 */
export declare class ErrorController {
    /**
     * Local instance of ErrorController. This is so that the same instance
     * is always returned.
     * @private
     * @static
     * @type {ErrorController}
     * @memberOf ErrorController
     */
    private static instance;
    /**
     * Maintain a mapping code=>error
     * @private
     * @type {Map<string, IError>}
     * @memberOf CommandController
     */
    private errorMap;
    /**
     * Interface used to process renderer errors.
     * @private
     * @type {IErrors}
     * @memberof ErrorController
     */
    private errorInterface;
    /**
     * A set containing all affected path.
     */
    private existingAffectedElementPathSet;
    /**
     * Creates an instance of ErrorController.
     * @param {IErrors} errorInterface
     * @memberof ErrorController
     */
    private constructor();
    /**
     * Clear all existing validation warn.
     *
     * @memberof ErrorController
     */
    clearExistingWarn(): void;
    /**
     * Used to register an error
     * @param {string} id
     * @param {IError} error
     * @memberOf CommandController
     */
    private registerError;
    /**
     * Register all renderer specific errors
     * @memberOf CommandController
     */
    registerErrors(): void;
    /**
     * Triggers a runtime error.
     * @param {string} code
     * @returns
     * @memberOf ErrorController
     */
    triggerRuntimeError(code: string): void;
    /**
     * Triggers a validation error.
     * @param {string} code
     * @param {object} position
     * @param {object} [placeholders={}]
     * @memberOf ErrorController
     */
    triggerValidationError(code: string, placeholders?: object): void;
    sendValidationError(validationError: IValidationError): void;
    /**
     * Sets instance to new ErrorController with supplied interface.
     * @static
     * @param {IErrorInterface} callback
     * @memberOf ErrorController
     */
    setErrorInterface(errorInterface: IErrorInterface): void;
    /**
     * Returns an instance of the ErrorController.
     * @static
     * @returns {ErrorController}
     * @memberOf ErrorController
     */
    static getInstance(): ErrorController;
}
