import { IAplComponent } from './IAplComponent';
/**
 * Used to extract components from APL template.
 * @export
 * @class AplComponentsExtractor
 */
export declare class AplComponentsExtractor {
    private ROOT_COMPONENT_TYPE;
    /**
     * Instance of AplComponentsExtractor.
     *
     * @private
     * @static
     * @type {AplComponentsExtractor}
     * @memberof AplComponentsExtractor
     */
    private static instance;
    private constructor();
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplComponentsExtractor}
     * @memberof AplComponentsExtractor
     */
    static getInstance(): AplComponentsExtractor;
    /**
     * Extract component from current APL template without parsing all components defined in import.
     * @param {object} aplTemplate
     * @returns {IAplComponent[]}
     * @memberof AplComponentsExtractor
     */
    extractComponents(aplTemplate: object): IAplComponent[];
    /**
     * Add current component. Also add child components if there are any.
     * @param component the current component to add
     * @param parentType direct parentType. Used to find mixin parent type later.
     * @param existingComponents list of AplComponents
     */
    private addComponent;
    private addChildComponents;
    private buildAplComponent;
    private isExtensionComponent;
    private generateMixinParent;
    private findMixinParent;
}
