/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CUSTOM_COMPONENT_SCHEMA_TEMPLATE = exports.CustomComponentJsonSchemaGenerator = void 0;
/**
 * This class is used to generate json schema for custom component.
 */
var CustomComponentJsonSchemaGenerator = /** @class */ (function () {
    function CustomComponentJsonSchemaGenerator() {
    }
    /**
     * Generate json schema based on the parameters.
     * @param data array of parameters.
     */
    CustomComponentJsonSchemaGenerator.generate = function (data) {
        var properties = {};
        data.forEach(function (eachItem) {
            CustomComponentJsonSchemaGenerator.generalizeParameter(eachItem, properties);
        });
        var result = CUSTOM_COMPONENT_SCHEMA_TEMPLATE();
        result.properties = properties;
        // Add default property type.
        result.properties.type = {
            type: 'string'
        };
        return result;
    };
    CustomComponentJsonSchemaGenerator.generalizeParameter = function (param, carry) {
        var propertyTemplate = {
            type: 'string'
        };
        if (typeof param === 'string') {
            carry[param] = propertyTemplate;
        }
        else if (param['name']) {
            var paramName = param['name'];
            var copiedTemplate = __assign({}, propertyTemplate);
            if (param['type']) {
                copiedTemplate.type = param['type'];
            }
            if (param['description']) {
                copiedTemplate.description = param['description'];
            }
            if (param['default']) {
                copiedTemplate.default = param['default'];
            }
            carry[paramName] = copiedTemplate;
        }
    };
    return CustomComponentJsonSchemaGenerator;
}());
exports.CustomComponentJsonSchemaGenerator = CustomComponentJsonSchemaGenerator;
/**
 * Template for custom component json schema.
 */
function CUSTOM_COMPONENT_SCHEMA_TEMPLATE() {
    return JSON.parse(JSON.stringify({
        $schema: 'https://json-schema.org/draft/2019-09/schema',
        definitions: {},
        type: 'object',
        properties: {},
        required: []
    }));
}
exports.CUSTOM_COMPONENT_SCHEMA_TEMPLATE = CUSTOM_COMPONENT_SCHEMA_TEMPLATE;
//# sourceMappingURL=CustomComponentJsonSchemaGenerator.js.map