/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoadState = exports.PackageLoader = void 0;
var axios_1 = require("axios");
var PREDEFINED_HOST = 'https://arl.assets.apl-alexa.com/packages';
var PREDEFINED_FILE_NAME = 'document.json';
var PREDEFINED_ARL_FILE_NAME = 'document-w-desc.json';
var ARL_PACKAGE_NAMES = ['alexa-layouts', 'alexa-styles', 'alexa-viewport-profiles'];
var STAGING_VERSION_REGEX = /^(?:\d+\.?)+-\w+$/;
/**
 *
 * Package loading theory.
 * 1. We start with a list of packages required.
 * 2. Each package in the list can be in one of the following states:
 *    a. Unloaded (not started yet)
 *    b. Loading (waiting for a response from the server)
 *    c. Loaded (waiting for a child to load)
 *    d. Finished (all children have loaded)
 *
 * @export
 * @class PackageLoader
 */
var PackageLoader = /** @class */ (function () {
    /**
     * Initialize PackageLoader attributes
     *
     * @param {object} embeddedPackages The package json file provided by the user
     *
     * @memberOf PackageLoader
     */
    function PackageLoader(embeddedPackages) {
        this.loadPackages = new Map();
        this.embeddedPackages = embeddedPackages;
        this.invalidPackages = [];
        this.loadSeries = 0;
    }
    /**
     *   Load import packages
     */
    PackageLoader.prototype.load = function (importPackages) {
        return __awaiter(this, void 0, void 0, function () {
            var packageNames;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.loadSeries += 1;
                        if (!importPackages) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.ensureLoaded(importPackages)];
                    case 1:
                        _a.sent();
                        packageNames = this.orderedPackageNames(importPackages);
                        return [2 /*return*/, this.namesToData(packageNames)];
                    case 2: return [2 /*return*/, []];
                }
            });
        });
    };
    /**
     * Flush loaded packages
     */
    PackageLoader.prototype.flush = function () {
        this.loadPackages.clear();
        this.invalidPackages = [];
        return;
    };
    /**
     * Walk a list of packages until all of them have been loaded.
     */
    PackageLoader.prototype.ensureLoaded = function (packageList) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        if (!Array.isArray(packageList)) {
                            resolve();
                            return;
                        }
                        var count = packageList.length;
                        if (count > 0) {
                            packageList.forEach(function (pkg) { return __awaiter(_this, void 0, void 0, function () {
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4 /*yield*/, this.loadPackage(pkg.name, pkg.version, pkg.source, packageList.indexOf(pkg))];
                                        case 1:
                                            _a.sent();
                                            count -= 1;
                                            if (count === 0) {
                                                resolve();
                                            }
                                            return [2 /*return*/];
                                    }
                                });
                            }); });
                        }
                        else {
                            resolve();
                        }
                    })];
            });
        });
    };
    /**
     * Check if version is a prod version
     * Version string shouldn't match staging version pattern: eg. 1.4.0-sadhsagfydavchgah
     */
    PackageLoader.prototype.isProdVersion = function (version) {
        return version.match(STAGING_VERSION_REGEX) == null;
    };
    /**
     * Execute a package load.  For now we ignore version
     */
    PackageLoader.prototype.loadPackage = function (name, version, url, idx) {
        return __awaiter(this, void 0, void 0, function () {
            var data, pkg_1, fileName;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.loadPackages.get(name)) return [3 /*break*/, 1];
                        data = this.loadPackages.get(name);
                        if (data.state === LoadState.done) {
                            return [2 /*return*/, Promise.resolve()];
                        }
                        return [3 /*break*/, 5];
                    case 1:
                        this.loadPackages.set(name, {
                            state: LoadState.load,
                            loadSeries: this.loadSeries,
                            json: undefined
                        });
                        pkg_1 = this.loadPackages.get(name);
                        // If we're trying to load from pre-defined packages, hardcoded url
                        // More information:
                        // https://wiki.labcollab.net/confluence/pages/viewpage.action?spaceKey=
                        // Doppler&title=Adding+or+editing+Alexa-provided+%28APML%29+Packages
                        // Pre-defined packages can be override by customer provided package json file
                        if (!url && !this.embeddedPackages[name]) {
                            fileName = ARL_PACKAGE_NAMES.includes(name) && version && this.isProdVersion(version)
                                ? PREDEFINED_ARL_FILE_NAME
                                : PREDEFINED_FILE_NAME;
                            url = "".concat(PREDEFINED_HOST, "/").concat(name, "/").concat(version, "/").concat(fileName);
                        }
                        if (!url) return [3 /*break*/, 2];
                        return [2 /*return*/, axios_1.default.get(url).then(function (response) {
                                return response.data;
                            }).then(function (jsonResponse) { return __awaiter(_this, void 0, void 0, function () {
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            pkg_1.json = this.deepFreeze(jsonResponse);
                                            pkg_1.state = LoadState.loadChildren;
                                            return [4 /*yield*/, this.ensureLoaded(pkg_1.json['import'])];
                                        case 1:
                                            _a.sent();
                                            pkg_1.state = LoadState.done;
                                            return [2 /*return*/, Promise.resolve()];
                                    }
                                });
                            }); }).catch(function (error) {
                                pkg_1.json = {};
                                pkg_1.state = LoadState.done;
                                pkg_1.error = error;
                                return Promise.resolve();
                            })];
                    case 2:
                        if (!!this.embeddedPackages[name]) return [3 /*break*/, 3];
                        this.invalidPackages.push(name);
                        return [3 /*break*/, 5];
                    case 3:
                        pkg_1.json = this.deepFreeze(this.embeddedPackages[name]['document']);
                        pkg_1.state = LoadState.loadChildren;
                        return [4 /*yield*/, this.ensureLoaded(this.embeddedPackages[name]['document'].import)];
                    case 4:
                        _a.sent();
                        pkg_1.state = LoadState.done;
                        return [2 /*return*/, Promise.resolve()];
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    /**
     *  Walk a list of packages and return all dependencies in order.
     *  Those two functions are following the depth-first search, following the package import order.
     */
    PackageLoader.prototype.orderedPackageNames = function (packageList) {
        if (packageList.length === 0) {
            return [];
        }
        // filter out invalid packages first
        packageList = packageList.filter(function (e) {
            return this.indexOf(e.name) < 0;
        }, this.invalidPackages);
        var sorted = [];
        var visited = {};
        for (var _i = 0, packageList_1 = packageList; _i < packageList_1.length; _i++) {
            var pkg = packageList_1[_i];
            this.addPackageNames(pkg, [], sorted, visited);
        }
        sorted.reverse();
        return sorted;
    };
    /**
     *   Embeded function for orderedPackageNames.
     *   Depth first search a list of packages and return all dependencies in order.
     */
    PackageLoader.prototype.addPackageNames = function (pkg, ancestors, sorted, visited) {
        var name = pkg.name;
        ancestors.push(name);
        visited[name] = true;
        var dependentList = this.loadPackages.get(name).json['import'] || [];
        // push the first package into sorted list
        if (sorted.indexOf(name) < 0) {
            sorted.push(name);
        }
        for (var _i = 0, dependentList_1 = dependentList; _i < dependentList_1.length; _i++) {
            var dep = dependentList_1[_i];
            // if find a circle import, exit
            if (ancestors.indexOf(dep.name) >= 0 || visited[dep.name]) {
                // if the dep is already visited before, need adjust order
                // to make sure the resources will be loaded in correct order
                var idx = sorted.indexOf(name);
                var childIdx = sorted.indexOf(dep.name);
                if (idx > childIdx) {
                    sorted[childIdx] = name;
                    sorted[idx] = dep.name;
                }
                return;
            }
            if (sorted.indexOf(dep.name) < 0) {
                sorted.push(dep.name);
            }
            this.addPackageNames(dep, ancestors.slice(), sorted, visited);
        }
    };
    /*
     * This is the actual data structure that will be returned by the loader.  In other words,
     * you will receive an array, where each item in the array is of the form:
     *
     * [
     *   { "name": NAME, "json": JSON, justLoaded: true/false },
     *   :
     * ]
     *
     * The list of packages is in resource order; later packages should override earlier.
     */
    PackageLoader.prototype.namesToData = function (packageNames) {
        var _this = this;
        return packageNames.map(function (name) {
            return {
                name: name,
                json: _this.loadPackages.get(name).json,
                justLoaded: _this.loadPackages.get(name).loadSeries === _this.loadSeries,
                error: _this.loadPackages.get(name).error
            };
        });
    };
    /**
     *   Deep-freeze object to ensure JSON is never modified
     */
    PackageLoader.prototype.deepFreeze = function (obj) {
        return JSON.parse(JSON.stringify(obj));
    };
    return PackageLoader;
}());
exports.PackageLoader = PackageLoader;
/**
 * Loading process contains:
 * - load : start loading this package
 * - loadChildren : start loading the children of this package
 * - done : finish loading this package
 *
 * @export
 * @enum {number}
 */
var LoadState;
(function (LoadState) {
    LoadState[LoadState["load"] = 'load'] = "load";
    LoadState[LoadState["loadChildren"] = 'loadChildren'] = "loadChildren";
    LoadState[LoadState["done"] = 'done'] = "done";
})(LoadState = exports.LoadState || (exports.LoadState = {}));
//# sourceMappingURL=PackageLoader.js.map