/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrimitiveComponentJsonSchemaUtil = void 0;
var ContainerJSONSchema = require("../assets/Container");
var FrameJSONSchema = require("../assets/Frame");
var ImageJSONSchema = require("../assets/Image");
var ScrollViewJSONSchema = require("../assets/ScrollView");
var SequenceJSONSchema = require("../assets/Sequence");
var TextJSONSchema = require("../assets/Text");
var VideoJSONSchema = require("../assets/Video");
var TouchWrapperJSONSchema = require("../assets/TouchWrapper");
var PagerJSONSchema = require("../assets/Pager");
var VectorGraphicJSONSchema = require("../assets/VectorGraphic");
var ContainerChildJSONSchema = require("../assets/ContainerChild");
var SequenceChildJSONSchema = require("../assets/SequenceChild");
var GridSequenceJSONSchema = require("../assets/GridSequence");
var GridSequenceChildJSONSchema = require("../assets/GridSequenceChild");
var EditTextJSONSchema = require("../assets/EditText");
var ExtensionComponentJSONSchema = require("../assets/ExtensionComponent");
/**
 * PrimitiveComponentJsonSchemaUtil.
 * @export
 * @class PrimitiveComponentJsonSchemaUtil
 */
var PrimitiveComponentJsonSchemaUtil = /** @class */ (function () {
    function PrimitiveComponentJsonSchemaUtil() {
    }
    PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema = function (componentType, aplVersion, parentComponentType) {
        var componentSchema = this.getJsonSchemaMap(aplVersion).get(componentType);
        if (!componentSchema) {
            return componentSchema;
        }
        var copiedSchema = JSON.parse(JSON.stringify(componentSchema));
        var result = parentComponentType ?
            this.merge(copiedSchema, this.getMixinJsonSchema(parentComponentType)) : copiedSchema;
        if (this.APL_1_0_VERSION === aplVersion) {
            this.filterBlacklistedProperty(componentType, result);
        }
        return result;
    };
    PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentTypes = function (aplVersion) {
        return Array.from(this.getJsonSchemaMap(aplVersion).keys());
    };
    PrimitiveComponentJsonSchemaUtil.getJsonSchemaMap = function (aplVersion) {
        if (this.APL_1_0_VERSION === aplVersion) {
            return this.COMPONENT_TYPE_TO_JSON_SCHEMA_APL_1_0;
        }
        return this.COMPONENT_TYPE_TO_JSON_SCHEMA;
    };
    /**
     * Find minin Json schema.
     * @param component component name
     */
    PrimitiveComponentJsonSchemaUtil.getMixinJsonSchema = function (component) {
        if (!this.COMPONENT_TYPE_TO_MIXIN_JSON_SCHEMA.has(component)) {
            console.warn('No mixin for component : ' + component);
            return undefined;
        }
        var result = this.COMPONENT_TYPE_TO_MIXIN_JSON_SCHEMA.get(component);
        if (!result) {
            console.warn("Failed to find layoutType for component : ".concat(component));
        }
        return result;
    };
    /**
     * Merge mixin json schema to component json schema.
     * @param originalSchema orginal component json schema.
     * @param mixin json schema to mixin.
     */
    PrimitiveComponentJsonSchemaUtil.merge = function (originalSchema, mixin) {
        if (!mixin) {
            return originalSchema;
        }
        var mixinProperties = mixin.properties;
        var originalProperties = originalSchema.properties;
        originalSchema.properties = __assign(__assign({}, originalProperties), mixinProperties);
        return originalSchema;
    };
    PrimitiveComponentJsonSchemaUtil.filterBlacklistedProperty = function (componentType, jsonSchema) {
        var blacklistedProperties = this.COMPONENT_TYPE_TO_PROPERTIES
            .get(componentType);
        Object.keys(jsonSchema.properties).forEach(function (element) {
            if (blacklistedProperties && blacklistedProperties.includes(element)) {
                delete jsonSchema.properties[element];
            }
        });
    };
    /**
     * APL 1.0 version string.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    PrimitiveComponentJsonSchemaUtil.APL_1_0_VERSION = '1.0';
    /**
     * All supported primitive component type in APL 1.0 to json schema mapping.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    PrimitiveComponentJsonSchemaUtil.COMPONENT_TYPE_TO_JSON_SCHEMA_APL_1_0 = new Map([
        ['Container', ContainerJSONSchema.JSON_SCHEMA],
        ['Frame', FrameJSONSchema.JSON_SCHEMA],
        ['Image', ImageJSONSchema.JSON_SCHEMA],
        ['ScrollView', ScrollViewJSONSchema.JSON_SCHEMA],
        ['Sequence', SequenceJSONSchema.JSON_SCHEMA],
        ['Text', TextJSONSchema.JSON_SCHEMA],
        ['TouchWrapper', TouchWrapperJSONSchema.JSON_SCHEMA],
        ['Video', VideoJSONSchema.JSON_SCHEMA],
        ['Pager', PagerJSONSchema.JSON_SCHEMA]
    ]);
    /**
     * All supported primitive component type to json schema mapping.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    PrimitiveComponentJsonSchemaUtil.COMPONENT_TYPE_TO_JSON_SCHEMA = new Map([
        ['Container', ContainerJSONSchema.JSON_SCHEMA],
        ['Frame', FrameJSONSchema.JSON_SCHEMA],
        ['Image', ImageJSONSchema.JSON_SCHEMA],
        ['ScrollView', ScrollViewJSONSchema.JSON_SCHEMA],
        ['Sequence', SequenceJSONSchema.JSON_SCHEMA],
        ['Text', TextJSONSchema.JSON_SCHEMA],
        ['TouchWrapper', TouchWrapperJSONSchema.JSON_SCHEMA],
        ['Video', VideoJSONSchema.JSON_SCHEMA],
        ['Pager', PagerJSONSchema.JSON_SCHEMA],
        ['VectorGraphic', VectorGraphicJSONSchema.JSON_SCHEMA],
        ['GridSequence', GridSequenceJSONSchema.JSON_SCHEMA],
        ['EditText', EditTextJSONSchema.JSON_SCHEMA],
        ['ExtensionComponent', ExtensionComponentJSONSchema.JSON_SCHEMA]
    ]);
    /**
     * All supported mixin type to json schema mapping.
     * The extra properties for their child components.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    PrimitiveComponentJsonSchemaUtil.COMPONENT_TYPE_TO_MIXIN_JSON_SCHEMA = new Map([
        ['Container', ContainerChildJSONSchema.JSON_SCHEMA],
        ['Sequence', SequenceChildJSONSchema.JSON_SCHEMA],
        ['GridSequence', GridSequenceChildJSONSchema.JSON_SCHEMA]
    ]);
    /**
     * properties are added after APL 1.0.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    PrimitiveComponentJsonSchemaUtil.COMPONENT_TYPE_TO_PROPERTIES = new Map([
        ['Container', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['Frame', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['Image', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel']],
        ['ScrollView', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['Sequence', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['Text', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['TouchWrapper', ['description', 'checked', 'display', 'onMount', 'transform',
                'accessibilityLabel', 'opacity']],
        ['Video', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform', 'onTimeUpdate',
                'accessibilityLabel', 'opacity']],
        ['Pager', ['description', 'checked', 'disabled', 'display', 'onMount', 'transform', 'onPageChanged',
                'accessibilityLabel', 'opacity']]
    ]);
    return PrimitiveComponentJsonSchemaUtil;
}());
exports.PrimitiveComponentJsonSchemaUtil = PrimitiveComponentJsonSchemaUtil;
//# sourceMappingURL=PrimitiveComponentJsonSchemaUtil.js.map