/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var CustomComponentJsonSchemaGenerator_1 = require("../CustomComponentJsonSchemaGenerator");
var chai_1 = require("chai");
describe('Custom component json schema generator.', function () {
    it('should generate json schema correctly.', function () {
        var jsonSchema = CustomComponentJsonSchemaGenerator_1.CustomComponentJsonSchemaGenerator.generate(['param1', 'param2']);
        var expectedJsonSchema = (0, CustomComponentJsonSchemaGenerator_1.CUSTOM_COMPONENT_SCHEMA_TEMPLATE)();
        expectedJsonSchema.properties = {
            param1: {
                type: 'string'
            },
            param2: {
                type: 'string'
            },
            type: {
                type: 'string'
            }
        };
        (0, chai_1.expect)(jsonSchema).to.deep.equal(expectedJsonSchema);
    });
    it('should generate json schema correctly when parameter is object.', function () {
        var jsonSchema = CustomComponentJsonSchemaGenerator_1.CustomComponentJsonSchemaGenerator.generate([
            {
                name: 'param1',
                description: 'Primary text to render in header.',
                type: 'string'
            },
            {
                name: 'param2',
                description: 'Secondary text to render in header.',
                type: 'boolean'
            }
        ]);
        var expectedJsonSchema = (0, CustomComponentJsonSchemaGenerator_1.CUSTOM_COMPONENT_SCHEMA_TEMPLATE)();
        expectedJsonSchema.properties = {
            type: {
                type: 'string'
            },
            param1: {
                type: 'string',
                description: 'Primary text to render in header.'
            },
            param2: {
                type: 'boolean',
                description: 'Secondary text to render in header.'
            }
        };
        (0, chai_1.expect)(jsonSchema).to.deep.equal(expectedJsonSchema);
    });
});
//# sourceMappingURL=CustomComponentJsonSchemaGenerator.spec.js.map