"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var CustomComponentsExtractor_1 = require("../CustomComponentsExtractor");
var sinon = require("sinon");
var importInternalTemplate_1 = require("./template_test_cases/importInternalTemplate");
var configs_1 = require("../../configs");
var ThirdPartyComponentsLoader_1 = require("../ThirdPartyComponentsLoader");
describe('CustomComponentsExtractor tests', function () {
    var stub;
    var customComponentsExtractor = CustomComponentsExtractor_1.CustomComponentsExtractor.getInstance();
    afterEach(function () {
        stub.restore();
    });
    it('should extract all including imported components', function () { return __awaiter(void 0, void 0, void 0, function () {
        var apl, componentsWithoutMainTemplate;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    stubAlexaLayout(importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_13);
                    apl = (0, configs_1.getSampleTemplate)(configs_1.SampleTemplateName.TEXT_LIST).apl;
                    return [4 /*yield*/, customComponentsExtractor.extractCustomComponents(apl)];
                case 1:
                    componentsWithoutMainTemplate = _a.sent();
                    (0, chai_1.expect)(componentsWithoutMainTemplate.getCustomComponentNames()).to.have.lengthOf(2);
                    (0, chai_1.expect)(Object.keys(componentsWithoutMainTemplate.getCustomComponentJsonSchema('AlexaHeader').properties)).
                        to.have.lengthOf(10);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all including imported component types for APL 1.0', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, extractComponents(importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_10, 5)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all including imported component types which are exported for APL 1.3+', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, extractComponents(importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_13, 2)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    var extractComponents = function (json, expectedNumberOfComponents) { return __awaiter(void 0, void 0, void 0, function () {
        var apl, componentTypesWithoutMainTemplate;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    stubAlexaLayout(json);
                    apl = (0, configs_1.getSampleTemplate)(configs_1.SampleTemplateName.TEXT_LIST).apl;
                    return [4 /*yield*/, customComponentsExtractor
                            .getCustomComponentTypesAndValidate(apl)];
                case 1:
                    componentTypesWithoutMainTemplate = _a.sent();
                    (0, chai_1.expect)(componentTypesWithoutMainTemplate).to.have.lengthOf(expectedNumberOfComponents);
                    return [2 /*return*/];
            }
        });
    }); };
    var stubAlexaLayout = function (json) {
        stub = sinon.stub(ThirdPartyComponentsLoader_1.ThirdPartyComponentLoader.prototype, 'load').returns(new Promise(function (resolve) {
            resolve([{
                    json: json,
                    justLoaded: true,
                    name: 'alexa-layouts'
                }]);
        }));
    };
});
//# sourceMappingURL=CustomComponentsExtractor.spec.js.map