/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var JsonPathCompletor_1 = require("../JsonPathCompletor");
describe('Template Json Path Completor', function () {
    var templateCompletor;
    var APL_DOC = {
        mainTemplate: {
            items: {
                type: 'Container',
                items: [
                    {
                        type: 'Image'
                    },
                    {
                        type: 'AlexaHeader'
                    }
                ]
            }
        },
        layouts: {
            ListTemplate1: {
                item: [
                    {
                        type: 'Container',
                        items: [
                            {
                                type: 'Image'
                            },
                            {
                                type: 'AlexaHeader'
                            },
                            {
                                type: 'Sequence',
                                items: [
                                    {
                                        type: 'VerticalListItem'
                                    }
                                ]
                            }
                        ]
                    }
                ]
            },
            VerticalListItem: {
                item: {
                    type: 'Container',
                    items: [
                        '${listItem}'
                    ]
                }
            }
        }
    };
    it('should add path to different level json object', function () {
        templateCompletor = new JsonPathCompletor_1.JsonPathCompletor(APL_DOC);
        var result = templateCompletor.addJsonPath();
        (0, chai_1.expect)(result['layouts']['ListTemplate1'].JSON_PATH).to.be.equal('/layouts/ListTemplate1');
        (0, chai_1.expect)(result['layouts']['ListTemplate1']['item'][0].JSON_PATH).to.be.equal('/layouts/ListTemplate1/item/0');
        (0, chai_1.expect)(result['layouts']['ListTemplate1']['item'][0]['items'][0].JSON_PATH).
            to.be.equal('/layouts/ListTemplate1/item/0/items/0');
        (0, chai_1.expect)(result['layouts']['ListTemplate1']['item'][0]['items'][1].JSON_PATH).
            to.be.equal('/layouts/ListTemplate1/item/0/items/1');
        (0, chai_1.expect)(result['layouts']['ListTemplate1']['item'][0]['items'][2].JSON_PATH).
            to.be.equal('/layouts/ListTemplate1/item/0/items/2');
        (0, chai_1.expect)(result['layouts']['VerticalListItem'].JSON_PATH).to.be.equal('/layouts/VerticalListItem');
        (0, chai_1.expect)(result['layouts']['VerticalListItem']['item'].JSON_PATH)
            .to.be.equal('/layouts/VerticalListItem/item');
        (0, chai_1.expect)(result['mainTemplate'].JSON_PATH).to.be.equal('/mainTemplate');
        (0, chai_1.expect)(result['mainTemplate']['items'].JSON_PATH).to.be.equal('/mainTemplate/items');
        (0, chai_1.expect)(result['mainTemplate']['items']['items'][0].JSON_PATH).to.be.equal('/mainTemplate/items/items/0');
        (0, chai_1.expect)(result['mainTemplate']['items']['items'][1].JSON_PATH).to.be.equal('/mainTemplate/items/items/1');
        (0, chai_1.expect)(APL_DOC.hasOwnProperty('JSON_SCHEMA')).to.be.equal(false); // Orginal JSON object is not being modified.
    });
});
//# sourceMappingURL=JsonPathCompletor.spec.js.map