/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var axios_mock_adapter_1 = require("axios-mock-adapter");
var chai_1 = require("chai");
var PackageLoader_1 = require("../PackageLoader");
var importGUITemplate_1 = require("./template_test_cases/importGUITemplate");
var importInternalTemplate_1 = require("./template_test_cases/importInternalTemplate");
var packageJsonTemplate_1 = require("./template_test_cases/packageJsonTemplate");
describe('PackageLoader', function () {
    var packageLoader;
    it('should import from internal apl package, depth-first, following the package import order', function (done) {
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0'
            }];
        packageJsonTemplate_1.packageJson['alexa-gui']['document'] = packageJsonTemplate_1.INTERNAL_ALEXA_GUI_SOURCE;
        packageLoader = new PackageLoader_1.PackageLoader(packageJsonTemplate_1.packageJson);
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            (0, chai_1.expect)(packageName).to.eql(['alexa-styles-extend', 'anything', 'alexa-styles-classic', 'alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error ".concat(error));
        });
    });
    it('test case 2 should import from internal apl package, following the package import order', function (done) {
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0'
            }, {
                name: 'alexa-style',
                version: '1.0.0'
            }];
        var json = {
            'alexa-gui': {
                document: {
                    type: 'APL',
                    version: '1.0.0'
                }
            },
            'alexa-style': {
                document: {
                    type: 'APL',
                    version: '1.0.0'
                }
            }
        };
        packageLoader = new PackageLoader_1.PackageLoader(json);
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            (0, chai_1.expect)(packageName).to.eql(['alexa-style', 'alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error ".concat(error));
        });
    });
    it('should import from predefined apl package, depth-first, following the package import order', function (done) {
        var LAYOUT_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-layouts/1.0.0/document-w-desc.json';
        var STYLES_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-styles/1.0.0/document-w-desc.json';
        var VIEWPORT_PROFILES_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-viewport-profiles/1.0.0/document-w-desc.json';
        var importPackages = [{
                name: 'alexa-layouts',
                version: '1.0.0'
            }];
        var mock = new axios_mock_adapter_1.default(axios_1.default);
        mock.onGet(LAYOUT_URL).reply(200, importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_10);
        mock.onGet(STYLES_URL).reply(200, importInternalTemplate_1.IMPORT_STYLES_TEMPLATE);
        mock.onGet(VIEWPORT_PROFILES_URL).reply(200, importInternalTemplate_1.IMPORT_ALEXA_VIEWPORT_PROFILES);
        packageLoader = new PackageLoader_1.PackageLoader({});
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            (0, chai_1.expect)(packageName).to.eql(['alexa-viewport-profiles', 'alexa-styles', 'alexa-layouts']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error ".concat(error));
        });
    });
    it('should import from predefined apl package staging version', function (done) {
        var LAYOUT_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-layouts/'
            + '1.5.0-eifjccgidjvrhnurcfvkdhdbdjfejddeighgfhvhhtrj/document.json';
        var STYLES_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-styles/1.0.0/document-w-desc.json';
        var VIEWPORT_PROFILES_URL = 'https://arl.assets.apl-alexa.com/packages/alexa-viewport-profiles/1.0.0/document-w-desc.json';
        var importPackages = [{
                name: 'alexa-layouts',
                version: '1.5.0-eifjccgidjvrhnurcfvkdhdbdjfejddeighgfhvhhtrj'
            }];
        var mock = new axios_mock_adapter_1.default(axios_1.default);
        mock.onGet(LAYOUT_URL).reply(200, importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_10);
        mock.onGet(STYLES_URL).reply(200, importInternalTemplate_1.IMPORT_STYLES_TEMPLATE);
        mock.onGet(VIEWPORT_PROFILES_URL).reply(200, importInternalTemplate_1.IMPORT_ALEXA_VIEWPORT_PROFILES);
        packageLoader = new PackageLoader_1.PackageLoader({});
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            (0, chai_1.expect)(packageName).to.eql(['alexa-viewport-profiles', 'alexa-styles', 'alexa-layouts']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error ".concat(error));
        });
    });
    it('should be able to import from external apl package', function (done) {
        var URL = 'https://s3.amazonaws.com/apml-authoring-assets/urlTemplate.json';
        var importPackages = [{
                name: 'alexa-gui',
                version: '1.0.0',
                source: URL
            }];
        var mock = new axios_mock_adapter_1.default(axios_1.default);
        mock.onGet(URL).reply(200, importGUITemplate_1.IMPORT_GUI_TEMPLATE);
        packageLoader = new PackageLoader_1.PackageLoader({});
        packageLoader.load(importPackages)
            .then(function (result) {
            var packageName = result.map(function (pkg) {
                return pkg.name;
            });
            (0, chai_1.expect)(packageName).to.eql(['alexa-gui']);
            done();
        }).catch(function (error) {
            done("load should have been successful. test failing with error ".concat(error));
        });
    });
    it('should return error if arl package version is missing', function () { return __awaiter(void 0, void 0, void 0, function () {
        var importPackages, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    importPackages = [
                        {
                            name: 'alexa-layouts'
                        },
                        {
                            name: 'alexa-styles',
                            version: ''
                        }
                    ];
                    packageLoader = new PackageLoader_1.PackageLoader({});
                    return [4 /*yield*/, packageLoader.load(importPackages)];
                case 1:
                    result = _a.sent();
                    (0, chai_1.expect)(result.length).to.be.equal(2);
                    (0, chai_1.expect)(result[0].json).to.deep.equal({});
                    (0, chai_1.expect)(result[1].json).to.deep.equal({});
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=PackageLoader.spec.js.map