"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var PrimitiveComponentJsonSchemaUtil_1 = require("../PrimitiveComponentJsonSchemaUtil");
var ContainerJSONSchema = require("../../assets/Container");
var VectorGraphicJSONSchema = require("../../assets/VectorGraphic");
describe('PrimitiveComponentJsonSchemaUtil', function () {
    it('should primitive component types correctly.', function () {
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentTypes().length).to.be.equal(13);
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentTypes('1.0').length).to.be.equal(9);
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentTypes('1.3').length).to.be.equal(13);
    });
    it('should get primitive component schema correctly if apl version is 1.3.', function () {
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Container', '1.3'))
            .to.be.eql(ContainerJSONSchema.JSON_SCHEMA);
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('VectorGraphic', '1.3'))
            .to.be.eql(VectorGraphicJSONSchema.JSON_SCHEMA);
    });
    it('should get primitive component schema correctly if apl version is 1.0.', function () {
        (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('VectorGraphic', '1.0'))
            .to.be.equal(undefined); // not defined in APL 1.0
        var jsonschema = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Container', '1.0');
        (0, chai_1.expect)(jsonschema.properties['type']['type']).to.be.equal('string'); // Component
        (0, chai_1.expect)(jsonschema.properties['checked']).to.be.equal(undefined); // not defined in APL 1.0
    });
    it('should not let mixin support jsonSchema affect original component schema.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var jsonschema;
        return __generator(this, function (_a) {
            jsonschema = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Container', '1.0');
            (0, chai_1.expect)(jsonschema.properties['checked']).to.be.equal(undefined); // not defined in APL 1.0
            (0, chai_1.expect)(PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Container', '1.3'))
                .to.be.eql(ContainerJSONSchema.JSON_SCHEMA);
            return [2 /*return*/];
        });
    }); });
    it('should generate correct Json schema with mixin support.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var jsonschema;
        return __generator(this, function (_a) {
            jsonschema = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Image', '1.0', 'Container');
            (0, chai_1.expect)(jsonschema.properties['type']['type']).to.be.equal('string'); // Component
            (0, chai_1.expect)(jsonschema.properties['checked']).to.be.equal(undefined); // not defined in APL 1.0
            (0, chai_1.expect)(jsonschema.properties['id']['type']).to.be.equal('string'); // Component
            (0, chai_1.expect)(jsonschema.properties['source']['$ref']).to.be.equal('#/definitions/Source'); // Image
            (0, chai_1.expect)(jsonschema.properties['grow']['type']).to.be.equal('number'); // ContainerChild
            (0, chai_1.expect)(jsonschema.properties['numbering']['type']).to.be.equal('string'); // ContainerChild
            return [2 /*return*/];
        });
    }); });
    it('should not let mixin support jsonSchema affect original component schema.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var jsonschemaWithMixin, originalSchema;
        return __generator(this, function (_a) {
            jsonschemaWithMixin = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Image', '1.0', 'Container');
            (0, chai_1.expect)(jsonschemaWithMixin.properties['grow']['type']).to.be.equal('number'); // mixin type
            (0, chai_1.expect)(jsonschemaWithMixin.properties.hasOwnProperty('overlayGradient')).to.be.equal(true);
            originalSchema = PrimitiveComponentJsonSchemaUtil_1.PrimitiveComponentJsonSchemaUtil.getPrimitiveComponentSchema('Image', '1.0');
            (0, chai_1.expect)(originalSchema.properties['grow']).to.be.equal(undefined); // mixin type
            return [2 /*return*/];
        });
    }); });
});
//# sourceMappingURL=PrimitiveComponentJsonSchemaUtil.spec.js.map