import { IAplCommand } from './IAplCommand';
/**
 * Used to extract Commands from APL template.
 * @export
 * @class AplCommandsExtractor
 */
export declare class AplCommandsExtractor {
    /**
     * All supported primitive component type to json schema mapping.
     * @static
     * @memberof PrimitiveComponentJsonSchemaUtil
     */
    private static COMMANDS_PROPERTIES_MAP;
    private static ARRAY_OF_COMMAND_PROPERTIES;
    /**
     * Instance of AplCommandsExtractor.
     *
     * @private
     * @static
     * @type {AplCommandsExtractor}
     * @memberof AplCommandsExtractor
     */
    private static instance;
    private constructor();
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplCommandsExtractor}
     * @memberof AplCommandsExtractor
     */
    static getInstance(): AplCommandsExtractor;
    /**
     * Extract Command from current APL template without parsing all Commands defined in import.
     * @param {object} aplTemplate
     * @returns {IAplCommand[]}
     * @memberof AplCommandsExtractor
     */
    extractCommands(aplTemplate: object): IAplCommand[];
    /**
     * Add current Command. Also add child Commands if there are any.
     * @param Command the current Command to add
     * @param existingCommands list of AplCommands
     */
    private addCommand;
    private addCommandArray;
    private addChildCommands;
    private buildAplCommand;
    private getCommandsProperties;
    /**
     * Add json path to commands object.
     * @returns {object} with json path information in commands.
     * @memberof JsonPathCompletor
     */
    private addJsonPath;
    /**
     * Recursion method to add json path to template.
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @returns
     */
    private addJsonPathToObject;
    /**
     * Process child element under commandsProperties.
     * @private
     * @param {object} currentObject
     * @param {string} currentPath
     * @param {string} element
     */
    private processChildCommand;
}
