import { IAplGraphic } from './IAplGraphic';
/**
 * Used to extract Graphics from APL template.
 * @export
 * @class AplGraphicsExtractor
 */
export declare class AplGraphicsExtractor {
    private ROOT_GRAPHICS_PATH;
    /**
     * Instance of AplGraphicsExtractor.
     *
     * @private
     * @static
     * @type {AplGraphicsExtractor}
     * @memberof AplGraphicsExtractor
     */
    private static instance;
    private constructor();
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplGraphicsExtractor}
     * @memberof AplGraphicsExtractor
     */
    static getInstance(): AplGraphicsExtractor;
    /**
     * Remove the JSON_PATH from the graphic
     * @param {object} aplTemplate
     * @returns {Promise<void>}
     * @memberOf AplGraphicsExtractor
     */
    clearJsonPath(aplTemplate: object): Promise<void>;
    /**
     * Extract Graphic from current APL template without parsing all Graphics defined in import.
     * @param {object} aplTemplate
     * @returns {IAplGraphic[]}
     * @memberof AplGraphicsExtractor
     */
    extractGraphics(aplTemplate: object): IAplGraphic[];
    /**
     * Add current Graphic. Also add child Graphics if there are any.
     * @param graphic the current Graphic to add
     * @param existingGraphics list of AplGraphics
     */
    private addGraphic;
    private addGraphicItems;
    private addChildGraphics;
    private buildAplGraphic;
}
