/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AplGraphicsExtractor = void 0;
var JsonPathCompletor_1 = require("../JsonPathCompletor");
/**
 * Used to extract Graphics from APL template.
 * @export
 * @class AplGraphicsExtractor
 */
var AplGraphicsExtractor = /** @class */ (function () {
    function AplGraphicsExtractor() {
        this.ROOT_GRAPHICS_PATH = 'graphics';
    }
    /**
     * Singleton method.
     *
     * @static
     * @returns {AplGraphicsExtractor}
     * @memberof AplGraphicsExtractor
     */
    AplGraphicsExtractor.getInstance = function () {
        if (!this.instance) {
            this.instance = new AplGraphicsExtractor();
        }
        return this.instance;
    };
    /**
     * Remove the JSON_PATH from the graphic
     * @param {object} aplTemplate
     * @returns {Promise<void>}
     * @memberOf AplGraphicsExtractor
     */
    AplGraphicsExtractor.prototype.clearJsonPath = function (aplTemplate) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!aplTemplate[this.ROOT_GRAPHICS_PATH]) return [3 /*break*/, 2];
                        return [4 /*yield*/, Promise.all(Object.values(aplTemplate[this.ROOT_GRAPHICS_PATH])
                                .map(function (value) {
                                if (typeof (value) === 'object' && value['type'] === 'AVG') {
                                    delete value['JSON_PATH'];
                                }
                            }))];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Extract Graphic from current APL template without parsing all Graphics defined in import.
     * @param {object} aplTemplate
     * @returns {IAplGraphic[]}
     * @memberof AplGraphicsExtractor
     */
    AplGraphicsExtractor.prototype.extractGraphics = function (aplTemplate) {
        var _this = this;
        var graphics = [];
        // add json path through completor. The completor also did deep copy of aplTemplate.
        var aplTemplateWithPath = new JsonPathCompletor_1.JsonPathCompletor(aplTemplate).addJsonPathToGraphics();
        // add graphics under graphics
        if (aplTemplateWithPath[this.ROOT_GRAPHICS_PATH]) {
            Object.values(aplTemplateWithPath[this.ROOT_GRAPHICS_PATH])
                .filter(function (value) { return typeof (value) === 'object' && value['type'] === 'AVG'; })
                .forEach(function (value) {
                _this.addGraphicItems(value, graphics);
            });
        }
        return graphics;
    };
    /**
     * Add current Graphic. Also add child Graphics if there are any.
     * @param graphic the current Graphic to add
     * @param existingGraphics list of AplGraphics
     */
    AplGraphicsExtractor.prototype.addGraphic = function (graphic, existingGraphics) {
        if (graphic['type'] === 'group') {
            this.addGraphicItems(graphic, existingGraphics);
        }
        var aplGraphic = this.buildAplGraphic(graphic);
        existingGraphics.push(aplGraphic);
    };
    AplGraphicsExtractor.prototype.addGraphicItems = function (graphic, existingGraphics) {
        if (graphic['items']) {
            this.addChildGraphics(graphic['items'], existingGraphics);
        }
        if (graphic['item']) {
            this.addChildGraphics(graphic['item'], existingGraphics);
        }
    };
    AplGraphicsExtractor.prototype.addChildGraphics = function (childGraphics, existingGraphics) {
        var _this = this;
        if (Array.isArray(childGraphics)) {
            childGraphics.forEach(function (Graphic) { return _this.addGraphic(Graphic, existingGraphics); });
        }
        else if (typeof (childGraphics) === 'object') {
            this.addGraphic(childGraphics, existingGraphics);
        }
    };
    AplGraphicsExtractor.prototype.buildAplGraphic = function (rawGraphic) {
        var jsonPath = rawGraphic[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        // delete unrelated properties
        delete rawGraphic[JsonPathCompletor_1.JsonPathCompletor.JSON_PATH];
        // indicate whether item/items exists but don't return the children. This replaced
        // outright deleting the properties which meant they would always error when required.
        if (rawGraphic['item']) {
            rawGraphic['item'] = [];
        }
        if (rawGraphic['items']) {
            rawGraphic['items'] = [];
        }
        return {
            jsonObject: rawGraphic,
            jsonPath: jsonPath,
            graphicType: rawGraphic['type']
        };
    };
    return AplGraphicsExtractor;
}());
exports.AplGraphicsExtractor = AplGraphicsExtractor;
//# sourceMappingURL=AplGraphicsExtractor.js.map