/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Seed = exports.ValidationSeed = void 0;
/**
 * Seed containing all components need to be validated.
 * @export
 * @class Validator
 */
var ValidationSeed = /** @class */ (function () {
    /**
     * Constructor.
     * @param seedComponent current component.
     * @param childComponents child components.
     * @param parentComponent parent component.
     */
    function ValidationSeed(seedComponent, parentComponent) {
        this.seedComponent = seedComponent;
        this.parentComponent = parentComponent;
    }
    /**
     * Return current component.
     */
    ValidationSeed.prototype.getSeedComponent = function () {
        return this.seedComponent;
    };
    ValidationSeed.prototype.getParentComponet = function () {
        return this.parentComponent;
    };
    return ValidationSeed;
}());
exports.ValidationSeed = ValidationSeed;
/**
 * Seed class containing raw seed and actual values.
 */
var Seed = /** @class */ (function () {
    function Seed(actualSeed, jsonPath) {
        this.actualSeed = actualSeed;
        this.jsonPath = jsonPath;
    }
    /**
     * Fetch value
     * @param {string} key
     * @returns {*}
     * @memberof Seed
     */
    Seed.prototype.getValue = function (key) {
        return this.actualSeed[key];
    };
    /**
     * Fetch Json path
     * @returns {string} json path
     * @memberof Seed
     */
    Seed.prototype.getJsonPath = function () {
        return this.jsonPath;
    };
    return Seed;
}());
exports.Seed = Seed;
//# sourceMappingURL=ValidationSeed.js.map