/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbsoluteDimensionRule = void 0;
var IValidationInfo_1 = require("../../IValidationInfo");
/**
 * Validaiton Rule to parse out non absolute value.
 * @export
 * @class AbsoluteDimensionRule
 */
var AbsoluteDimensionRule = /** @class */ (function () {
    function AbsoluteDimensionRule() {
    }
    /**
     * Entrance method to apply the rule.
     * @param sourceObject object to parse.
     * @param key key to parse.
     * @param collectors used to collect all validation info.
     */
    AbsoluteDimensionRule.applyRule = function (sourceObject, key, collectors, context) {
        var valueToCheck = sourceObject.getValue(key);
        if (!valueToCheck || !isNaN(valueToCheck)
            // todo: Remove after evaluation is implemented
            || valueToCheck.startsWith('@') || valueToCheck.startsWith('$')) {
            return;
        }
        var regexp = new RegExp('.*\.(px|dp|vh|vw)$');
        if (regexp.test(valueToCheck)) {
            return;
        }
        var finalContext = context ? context : "".concat(sourceObject.getValue('type'), " ").concat(key);
        collectors.push({
            path: "".concat(sourceObject.getJsonPath(), "/").concat(key),
            errorMessage: "".concat(finalContext, " must be a number or string that ends with \"px\", \"dp\", \"vh\", or \"vw\""),
            level: IValidationInfo_1.NotificationLevel.WARN
        });
    };
    return AbsoluteDimensionRule;
}());
exports.AbsoluteDimensionRule = AbsoluteDimensionRule;
//# sourceMappingURL=AbsoluteDimensionRule.js.map