/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.MustHaveField = void 0;
var IValidationInfo_1 = require("../../IValidationInfo");
/**
 * Check whether have a specific field.
 * @export
 * @class MustHaveField
 */
var MustHaveField = /** @class */ (function () {
    function MustHaveField() {
    }
    /**
     * Entrance method to apply the rule.
     * @param sourceObject object to parse.
     * @param collectors used to collect all validation info.
     * @param keys
     */
    MustHaveField.applyRule = function (sourceObject, keys, collectors) {
        var missingFields = [];
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            if (!sourceObject.getValue(key)) {
                missingFields.push(key);
            }
        }
        var jsonPath = sourceObject.getJsonPath();
        var type = sourceObject.getValue('type');
        if (missingFields.length > 0) {
            collectors.push({
                path: jsonPath,
                errorMessage: "".concat(type, " width and height must be defined. If the value is not defined, then default value is set to 100px."),
                level: IValidationInfo_1.NotificationLevel.WARN
            });
        }
    };
    return MustHaveField;
}());
exports.MustHaveField = MustHaveField;
//# sourceMappingURL=MustHaveField.js.map