/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotRelativeRule = void 0;
var IValidationInfo_1 = require("../../IValidationInfo");
/**
 * Validaiton Rule to parse out relative value.
 * @export
 * @class NotRelativeRule
 */
var NotRelativeRule = /** @class */ (function () {
    function NotRelativeRule() {
    }
    /**
     * Entrance method to apply the rule.
     * @param sourceObject object to parse.
     * @param key key to parse.
     * @param collectors used to collect all validation info.
     */
    NotRelativeRule.applyRule = function (sourceObject, key, collectors, context, overrideMessage) {
        var valueToCheck = sourceObject.getValue(key);
        if (!valueToCheck || typeof (valueToCheck) === 'number'
            // todo: Remove after evaluation is implemented
            || valueToCheck.startsWith('@') || valueToCheck.startsWith('$')) {
            return;
        }
        var regexp = new RegExp('.*\.%$');
        if (regexp.test(valueToCheck)) {
            var finalErrorContext = context ? context : "".concat(sourceObject.getValue('type'));
            var finalMessage = overrideMessage ? overrideMessage : "".concat(finalErrorContext, " should be an absolute or auto value.");
            collectors.push({
                path: "".concat(sourceObject.getJsonPath(), "/").concat(key),
                errorMessage: finalMessage,
                level: IValidationInfo_1.NotificationLevel.WARN
            });
        }
    };
    return NotRelativeRule;
}());
exports.NotRelativeRule = NotRelativeRule;
//# sourceMappingURL=NotRelativeRule.js.map