/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComponentValidator = void 0;
var NotAutoRule_1 = require("../rules/NotAutoRule");
var AbsoluteDimensionRule_1 = require("../rules/AbsoluteDimensionRule");
var NotRelativeRule_1 = require("../rules/NotRelativeRule");
/**
 * ComponentValidator.
 * @export
 * @class ComponentValidator.
 */
var ComponentValidator = /** @class */ (function () {
    function ComponentValidator() {
        this.ROOT_COMPONENT_TYPE = 'mainTemplate';
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    ComponentValidator.prototype.validate = function (validationSeed) {
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'paddingLeft', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'paddingRight', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'paddingTop', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'paddingBottom', results);
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'minWidth', results);
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'maxWidth', results);
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'minHeight', results);
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'maxHeight', results);
        this.childNotRelativeWhenParentIsAuto(validationSeed, 'width', results);
        this.childNotRelativeWhenParentIsAuto(validationSeed, 'height', results);
        return results;
    };
    ComponentValidator.prototype.childNotRelativeWhenParentIsAuto = function (validationSeed, fieldToCheck, collectors) {
        // If there is no parent compent or parent compent is root then no need to check.
        if (!validationSeed.getParentComponet()
            || validationSeed.getParentComponet().getValue('type') === this.ROOT_COMPONENT_TYPE) {
            return;
        }
        if (!validationSeed.getParentComponet().getValue(fieldToCheck)
            || validationSeed.getParentComponet().getValue(fieldToCheck) === 'auto') {
            var type = validationSeed.getSeedComponent().getValue('type');
            NotRelativeRule_1.NotRelativeRule.applyRule(validationSeed.getSeedComponent(), fieldToCheck, collectors, '', "".concat(type, " ").concat(fieldToCheck, " must be an absolute value when the parent ").concat(fieldToCheck, " is set to auto."));
        }
    };
    return ComponentValidator;
}());
exports.ComponentValidator = ComponentValidator;
//# sourceMappingURL=ComponentValidator.js.map