/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContainerComponentValidator = void 0;
var NotAutoRule_1 = require("../rules/NotAutoRule");
var AbsoluteDimensionRule_1 = require("../rules/AbsoluteDimensionRule");
/**
 * ContainerComponentValidator.
 * @export
 * @class ContainerComponentValidator.
 */
var ContainerComponentValidator = /** @class */ (function () {
    function ContainerComponentValidator() {
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    ContainerComponentValidator.prototype.validate = function (validationSeed) {
        if (!validationSeed.getParentComponet()
            || validationSeed.getParentComponet().getValue('type') !== 'Container') {
            return [];
        }
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'spacing', results, 'Container child spacing');
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'top', results, 'Container child top');
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'left', results, 'Container child left');
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'bottom', results, 'Container child bottom');
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'right', results, 'Container child right');
        return results;
    };
    return ContainerComponentValidator;
}());
exports.ContainerComponentValidator = ContainerComponentValidator;
//# sourceMappingURL=ContainerComponentValidator.js.map