/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.FrameComponentValidator = void 0;
var AbsoluteDimensionRule_1 = require("../rules/AbsoluteDimensionRule");
/**
 * Validator to validate Frame component.
 * @export
 * @class FrameComponentValidator
 */
var FrameComponentValidator = /** @class */ (function () {
    function FrameComponentValidator() {
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    FrameComponentValidator.prototype.validate = function (validationSeed) {
        if (validationSeed.getSeedComponent().getValue('type') !== 'Frame') {
            return [];
        }
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderRadius', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderBottomLeftRadius', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderBottomRightRadius', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderTopLeftRadius', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderTopRightRadius', results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderWidth', results);
        return results;
    };
    return FrameComponentValidator;
}());
exports.FrameComponentValidator = FrameComponentValidator;
//# sourceMappingURL=FrameComponentValidator.js.map