/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageComponentValidator = void 0;
var NotAutoRule_1 = require("../rules/NotAutoRule");
var MustHaveField_1 = require("../rules/MustHaveField");
var AbsoluteDimensionRule_1 = require("../rules/AbsoluteDimensionRule");
/**
 * ImageComponentValidator.
 * @export
 * @class ImageComponentValidator
 */
var ImageComponentValidator = /** @class */ (function () {
    function ImageComponentValidator() {
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    ImageComponentValidator.prototype.validate = function (validationSeed) {
        if (validationSeed.getSeedComponent().getValue('type') !== 'Image') {
            return [];
        }
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'height', results);
        NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'width', results);
        MustHaveField_1.MustHaveField.applyRule(seedComponent, ['height', 'width'], results);
        AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'borderRadius', results);
        return results;
    };
    return ImageComponentValidator;
}());
exports.ImageComponentValidator = ImageComponentValidator;
//# sourceMappingURL=ImageComponentValidator.js.map