/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrollViewComponentValidator = void 0;
var NotAutoRule_1 = require("../rules/NotAutoRule");
var NotRelativeRule_1 = require("../rules/NotRelativeRule");
/**
 * ScrollViewComponentValidator.
 * @export
 * @class ScrollViewComponentValidator
 */
var ScrollViewComponentValidator = /** @class */ (function () {
    function ScrollViewComponentValidator() {
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    ScrollViewComponentValidator.prototype.validate = function (validationSeed) {
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        if (seedComponent.getValue('type') === 'ScrollView') {
            NotAutoRule_1.NotAutoRule.applyRule(seedComponent, 'height', results);
        }
        if (!validationSeed.getParentComponet()
            || validationSeed.getParentComponet().getValue('type') !== 'ScrollView') {
            return results;
        }
        var errorMessage = "ScrollView child ".concat(seedComponent.getValue('type'));
        NotRelativeRule_1.NotRelativeRule.applyRule(seedComponent, 'height', results, errorMessage);
        return results;
    };
    return ScrollViewComponentValidator;
}());
exports.ScrollViewComponentValidator = ScrollViewComponentValidator;
//# sourceMappingURL=ScrollViewComponentValidator.js.map