/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.SequenceComponentValidator = void 0;
var NotAutoRule_1 = require("../rules/NotAutoRule");
var NotRelativeRule_1 = require("../rules/NotRelativeRule");
var AbsoluteDimensionRule_1 = require("../rules/AbsoluteDimensionRule");
/**
 * SequenceComponentValidator.
 * @export
 * @class SequenceComponentValidator
 */
var SequenceComponentValidator = /** @class */ (function () {
    function SequenceComponentValidator() {
    }
    /**
     * Validate given object.
     * @param validationSeed seed to validate.
     */
    SequenceComponentValidator.prototype.validate = function (validationSeed) {
        var results = [];
        var seedComponent = validationSeed.getSeedComponent();
        var seedComponentCheck = this.getCheck(seedComponent);
        if (seedComponent.getValue('type') === 'Sequence' && seedComponentCheck.shouldCheck) {
            NotAutoRule_1.NotAutoRule.applyRule(seedComponent, seedComponentCheck.valueToCheck, results);
        }
        if (!validationSeed.getParentComponet() || validationSeed.getParentComponet().getValue('type') !== 'Sequence') {
            return results;
        }
        var parentComponet = validationSeed.getParentComponet();
        var childComponentCheck = this.getCheck(parentComponet);
        if (childComponentCheck.shouldCheck) {
            var valueToCheck = childComponentCheck.valueToCheck;
            NotRelativeRule_1.NotRelativeRule.applyRule(seedComponent, valueToCheck, results, 'Sequence child ' + valueToCheck);
            AbsoluteDimensionRule_1.AbsoluteDimensionRule.applyRule(seedComponent, 'spacing', results, 'Sequence child spacing');
        }
        return results;
    };
    SequenceComponentValidator.prototype.getCheck = function (seedComponent) {
        // Default scrollDirection is vertical.
        if (!seedComponent.getValue('scrollDirection') || seedComponent.getValue('scrollDirection') === 'vertical') {
            return { shouldCheck: true, valueToCheck: 'height' };
        }
        else if (seedComponent.getValue('scrollDirection') === 'horizontal') {
            return { shouldCheck: true, valueToCheck: 'width' };
        }
        return { shouldCheck: false };
    };
    return SequenceComponentValidator;
}());
exports.SequenceComponentValidator = SequenceComponentValidator;
//# sourceMappingURL=SequenceComponentValidator.js.map