/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var ValidationSeed_1 = require("../../ValidationSeed");
var ComponentValidator_1 = require("../ComponentValidator");
describe('ComponentValidator', function () {
    var componentValidator;
    beforeEach(function () {
        componentValidator = new ComponentValidator_1.ComponentValidator();
    });
    it('should report if height is auto, paddding* is not absolute and width must not be relative.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'AnyComponent',
            height: 'auto',
            width: '${variable}',
            paddingLeft: 'auto',
            paddingRight: '100%',
            paddingTop: '100%',
            paddingBottom: '100%',
            minWidth: 'auto',
            maxWidth: 'auto',
            minHeight: 'auto',
            maxHeight: 'auto'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'AnyComponent',
            height: '${heightVariable}',
            width: '100%'
        }));
        var results = componentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(8);
    });
    it('should report if height is not defined.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'AnyComponent',
            width: '100%',
            height: '100%'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'AnyComponent'
        }));
        var results = componentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(2);
    });
    it('should not report.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Container',
            top: '100px',
            left: '${leftVariable}',
            bottom: '${bottomVariable}',
            right: '100%',
            height: '100px'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'Container',
            paddingLeft: '100px',
            paddingRight: '100dp',
            paddingTop: 100,
            paddingBottom: '50px',
            minWidth: 'auto',
            maxWidth: 'auto',
            minHeight: 100,
            maxHeight: '50dp'
        }));
        var results = componentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
});
//# sourceMappingURL=ComponentValidator.spec.js.map