/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var ValidationSeed_1 = require("../../ValidationSeed");
var ContainerComponentValidator_1 = require("../ContainerComponentValidator");
describe('ContainerComponentValidator', function () {
    var containerComponentValidator;
    beforeEach(function () {
        containerComponentValidator = new ContainerComponentValidator_1.ContainerComponentValidator();
    });
    it('should report if child fields is auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'AnyComponent',
            top: 'auto',
            left: 'auto',
            bottom: 'auto',
            right: 'auto'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'Container',
            height: 'auto',
            letterSpacing: '100%'
        }));
        var results = containerComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(4);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/items/0/top');
        (0, chai_1.expect)(results[1].path).to.be.equal('/path/to/parent/items/0/left');
        (0, chai_1.expect)(results[2].path).to.be.equal('/path/to/parent/items/0/bottom');
        (0, chai_1.expect)(results[3].path).to.be.equal('/path/to/parent/items/0/right');
    });
    it('should not report if top, left, bottom, right are absolute.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Container',
            top: '100px',
            left: '78%',
            bottom: '100dp',
            right: '100%',
            height: '100px'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'Container',
            height: '100px',
            letterSpacing: '100dp'
        }));
        var results = containerComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should report if spacing in child is not absolute.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'AnyComponent',
            spacing: 'auto'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'Container',
            height: 'auto',
            letterSpacing: '100%'
        }));
        var results = containerComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/items/0/spacing');
    });
});
//# sourceMappingURL=ContainerComponentValidator.spec.js.map