/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var ValidationSeed_1 = require("../../ValidationSeed");
var ScrollViewComponentValidator_1 = require("../ScrollViewComponentValidator");
describe('ScrollViewComponentValidator', function () {
    var scrollViewComponentValidator;
    beforeEach(function () {
        scrollViewComponentValidator = new ScrollViewComponentValidator_1.ScrollViewComponentValidator();
    });
    it('should report if child has relative height.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Container',
            height: '70%'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'ScrollView'
        }));
        var results = scrollViewComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/items/0/height');
    });
    it('should not report if child height is absolute.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Container',
            height: '100px'
        }, '/path/to/parent/items/0'), new ValidationSeed_1.Seed({
            type: 'ScrollView'
        }));
        var results = scrollViewComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should report if height is auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'ScrollView',
            height: 'auto'
        }, '/path/to/parent'));
        var results = scrollViewComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/height');
    });
    it('should not report if height is absolute.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'ScrollView',
            height: '100px'
        }, '/path/to/parent'));
        var results = scrollViewComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
});
//# sourceMappingURL=ScrollViewComponentValidator.spec.js.map