/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var VideoComponentValidator_1 = require("../VideoComponentValidator");
var ValidationSeed_1 = require("../../ValidationSeed");
describe('VideoComponentValidator', function () {
    var videoComponentValidator;
    beforeEach(function () {
        videoComponentValidator = new VideoComponentValidator_1.VideoComponentValidator();
    });
    it('should report if width is auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            height: '100px',
            width: 'auto'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/width');
    });
    it('should report if height is auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            height: 'auto',
            width: '100px'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].errorMessage.indexOf('height')).to.be.greaterThan(-1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent/height');
    });
    it('should report if both height and width are auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            height: 'auto',
            width: 'auto'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(2);
    });
    it('should not report if none of height and width is auto.', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            height: '100px',
            width: '100%'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(0);
    });
    it('should report if height is not defined', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            width: '100px'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].errorMessage.indexOf('height')).to.be.greaterThan(-1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent');
    });
    it('should report if width is not defined', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video',
            height: '100px'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].errorMessage.indexOf('width')).to.be.greaterThan(-1);
        (0, chai_1.expect)(results[0].path).to.be.equal('/path/to/parent');
    });
    it('should report if width and height are not defined', function () {
        var seedComponent = new ValidationSeed_1.ValidationSeed(new ValidationSeed_1.Seed({
            type: 'Video'
        }, '/path/to/parent'));
        var results = videoComponentValidator.validate(seedComponent);
        (0, chai_1.expect)(results.length).to.be.equal(1);
        (0, chai_1.expect)(results[0].errorMessage.indexOf('height')).to.be.greaterThan(-1);
        (0, chai_1.expect)(results[0].errorMessage.indexOf('width')).to.be.greaterThan(-1);
    });
});
//# sourceMappingURL=VideoComponentValidator.spec.js.map